"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def post(
    hub,
    ctx,
    bot_name: str,
    bot_alias: str,
    user_id: str,
    content_type: str,
    input_stream: bytes,
    session_attributes: str = None,
    request_attributes: str = None,
    accept: str = None,
    active_contexts: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Sends user input (text or speech) to Amazon Lex. Clients use this API to send text and audio requests to Amazon Lex at runtime. Amazon Lex interprets the user input using the machine learning model that it built for the bot.  The PostContent operation supports audio input at 8kHz and 16kHz. You can use 8kHz audio to achieve higher speech recognition accuracy in telephone audio applications.   In response, Amazon Lex returns the next message to convey to the user. Consider the following example messages:     For a user input "I would like a pizza," Amazon Lex might return a response with a message eliciting slot data (for example, PizzaSize): "What size pizza would you like?".     After the user provides all of the pizza order information, Amazon Lex might return a response with a message to get user confirmation: "Order the pizza?".     After the user replies "Yes" to the confirmation prompt, Amazon Lex might return a conclusion statement: "Thank you, your cheese pizza has been ordered.".     Not all Amazon Lex messages require a response from the user. For example, conclusion statements do not require a response. Some messages require only a yes or no response. In addition to the message, Amazon Lex provides additional context about the message in the response that you can use to enhance client behavior, such as displaying the appropriate client user interface. Consider the following examples:     If the message is to elicit slot data, Amazon Lex returns the following context information:     x-amz-lex-dialog-state header set to ElicitSlot     x-amz-lex-intent-name header set to the intent name in the current context     x-amz-lex-slot-to-elicit header set to the slot name for which the message is eliciting information     x-amz-lex-slots header set to a map of slots configured for the intent with their current values       If the message is a confirmation prompt, the x-amz-lex-dialog-state header is set to Confirmation and the x-amz-lex-slot-to-elicit header is omitted.     If the message is a clarification prompt configured for the intent, indicating that the user intent is not understood, the x-amz-dialog-state header is set to ElicitIntent and the x-amz-slot-to-elicit header is omitted.     In addition, Amazon Lex also returns your application-specific sessionAttributes. For more information, see Managing Conversation Context.

    Args:
        bot_name(str): Name of the Amazon Lex bot.
        bot_alias(str): Alias of the Amazon Lex bot.
        user_id(str): The ID of the client application user. Amazon Lex uses this to identify a user's conversation with your bot. At runtime, each request must contain the userID field. To decide the user ID to use for your application, consider the following factors.   The userID field must not contain any personally identifiable information of the user, for example, name, personal identification numbers, or other end user personal information.   If you want a user to start a conversation on one device and continue on another device, use a user-specific identifier.   If you want the same user to be able to have two independent conversations on two different devices, choose a device-specific identifier.   A user can't have two independent conversations with two different versions of the same bot. For example, a user can't have a conversation with the PROD and BETA versions of the same bot. If you anticipate that a user will need to have conversation with two different versions, for example, while testing, include the bot alias in the user ID to separate the two conversations.  .
        session_attributes(str, optional): You pass this value as the x-amz-lex-session-attributes HTTP header. Application-specific information passed between Amazon Lex and a client application. The value must be a JSON serialized and base64 encoded map with string keys and values. The total size of the sessionAttributes and requestAttributes headers is limited to 12 KB. For more information, see Setting Session Attributes. Defaults to None.
        request_attributes(str, optional): You pass this value as the x-amz-lex-request-attributes HTTP header. Request-specific information passed between Amazon Lex and a client application. The value must be a JSON serialized and base64 encoded map with string keys and values. The total size of the requestAttributes and sessionAttributes headers is limited to 12 KB. The namespace x-amz-lex: is reserved for special attributes. Don't create any request attributes with the prefix x-amz-lex:. For more information, see Setting Request Attributes. Defaults to None.
        content_type(str):  You pass this value as the Content-Type HTTP header.   Indicates the audio format or text. The header value must start with one of the following prefixes:    PCM format, audio data must be in little-endian byte order.   audio/l16; rate=16000; channels=1   audio/x-l16; sample-rate=16000; channel-count=1   audio/lpcm; sample-rate=8000; sample-size-bits=16; channel-count=1; is-big-endian=false      Opus format   audio/x-cbr-opus-with-preamble; preamble-size=0; bit-rate=256000; frame-size-milliseconds=4     Text format   text/plain; charset=utf-8    .
        accept(str, optional):  You pass this value as the Accept HTTP header.   The message Amazon Lex returns in the response can be either text or speech based on the Accept HTTP header value in the request.     If the value is text/plain; charset=utf-8, Amazon Lex returns text in the response.     If the value begins with audio/, Amazon Lex returns speech in the response. Amazon Lex uses Amazon Polly to generate the speech (using the configuration you specified in the Accept header). For example, if you specify audio/mpeg as the value, Amazon Lex returns speech in the MPEG format.   If the value is audio/pcm, the speech returned is audio/pcm in 16-bit, little endian format.    The following are the accepted values:   audio/mpeg   audio/ogg   audio/pcm   text/plain; charset=utf-8   audio/* (defaults to mpeg)    . Defaults to None.
        input_stream(bytes):  User input in PCM or Opus audio format or text format as described in the Content-Type HTTP header.  You can stream audio data to Amazon Lex or you can create a local buffer that captures all of the audio data before sending. In general, you get better performance if you stream audio data rather than buffering the data locally.
        active_contexts(str, optional): A list of contexts active for the request. A context can be activated when a previous intent is fulfilled, or by including the context in the request, If you don't specify a list of contexts, Amazon Lex will use the current list of contexts for the session. If you specify an empty list, all contexts for the session are cleared. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_runtime.content.post(
                ctx,
                bot_name=value,
                bot_alias=value,
                user_id=value,
                content_type=value,
                input_stream=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_runtime.content.post bot_name=value, bot_alias=value, user_id=value, content_type=value, input_stream=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-runtime",
        operation="post_content",
        op_kwargs={
            "botName": bot_name,
            "botAlias": bot_alias,
            "userId": user_id,
            "sessionAttributes": session_attributes,
            "requestAttributes": request_attributes,
            "contentType": content_type,
            "accept": accept,
            "inputStream": input_stream,
            "activeContexts": active_contexts,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, name: str, voice_connector_items: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon Chime Voice Connector group under the administrator's AWS account. You can associate Amazon Chime Voice Connectors with the Amazon Chime Voice Connector group by including VoiceConnectorItems in the request. You can include Amazon Chime Voice Connectors from different AWS Regions in your group. This creates a fault tolerant mechanism for fallback in case of availability events.

    Args:
        name(str): The name of the Amazon Chime Voice Connector group.
        voice_connector_items(List, optional): The Amazon Chime Voice Connectors to route inbound calls to. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.group.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.group.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_voice_connector_group",
        op_kwargs={"Name": name, "VoiceConnectorItems": voice_connector_items},
    )


async def delete(hub, ctx, voice_connector_group_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified Amazon Chime Voice Connector group. Any VoiceConnectorItems and phone numbers associated with the group must be removed before it can be deleted.

    Args:
        voice_connector_group_id(str): The Amazon Chime Voice Connector group ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.group.delete(
                ctx, voice_connector_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.group.delete voice_connector_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_voice_connector_group",
        op_kwargs={"VoiceConnectorGroupId": voice_connector_group_id},
    )


async def get(hub, ctx, voice_connector_group_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Retrieves details for the specified Amazon Chime Voice Connector group, such as timestamps,name, and associated VoiceConnectorItems.

    Args:
        voice_connector_group_id(str): The Amazon Chime Voice Connector group ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.group.get(
                ctx, voice_connector_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.group.get voice_connector_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_voice_connector_group",
        op_kwargs={"VoiceConnectorGroupId": voice_connector_group_id},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the Amazon Chime Voice Connector groups for the administrator's AWS account.

    Args:
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_voice_connector_groups",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(
    hub, ctx, voice_connector_group_id: str, name: str, voice_connector_items: List
) -> Dict:
    r"""
    **Autogenerated function**

    Updates details of the specified Amazon Chime Voice Connector group, such as the name and Amazon Chime Voice Connector priority ranking.

    Args:
        voice_connector_group_id(str): The Amazon Chime Voice Connector group ID.
        name(str): The name of the Amazon Chime Voice Connector group.
        voice_connector_items(List): The VoiceConnectorItems to associate with the group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.group.update(
                ctx, voice_connector_group_id=value, name=value, voice_connector_items=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.group.update voice_connector_group_id=value, name=value, voice_connector_items=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_voice_connector_group",
        op_kwargs={
            "VoiceConnectorGroupId": voice_connector_group_id,
            "Name": name,
            "VoiceConnectorItems": voice_connector_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    status: str = None,
    target_selection: str = None,
    max_results: int = None,
    next_token: str = None,
    thing_group_name: str = None,
    thing_group_id: str = None,
    namespace_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists jobs.

    Args:
        status(str, optional): An optional filter that lets you search for jobs that have the specified status. Defaults to None.
        target_selection(str, optional): Specifies whether the job will continue to run (CONTINUOUS), or will be complete after all those things specified as targets have completed the job (SNAPSHOT). If continuous, the job may also be run on a thing when a change is detected in a target. For example, a job will run on a thing when the thing is added to a target group, even after the job was completed by all things originally in the group. . Defaults to None.
        max_results(int, optional): The maximum number of results to return per request. Defaults to None.
        next_token(str, optional): The token to retrieve the next set of results. Defaults to None.
        thing_group_name(str, optional): A filter that limits the returned jobs to those for the specified group. Defaults to None.
        thing_group_id(str, optional): A filter that limits the returned jobs to those for the specified group. Defaults to None.
        namespace_id(str, optional): The namespace used to indicate that a job is a customer-managed job. When you specify a value for this parameter, AWS IoT Core sends jobs notifications to MQTT topics that contain the value in the following format.  $aws/things/THING_NAME/jobs/JOB_ID/notify-namespace-NAMESPACE_ID/   The namespaceId feature is in public preview. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.jobs.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.jobs.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_jobs",
        op_kwargs={
            "status": status,
            "targetSelection": target_selection,
            "maxResults": max_results,
            "nextToken": next_token,
            "thingGroupName": thing_group_name,
            "thingGroupId": thing_group_id,
            "namespaceId": namespace_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    scheduled_action_name: str,
    target_action: Dict,
    schedule: str,
    iam_role: str,
    scheduled_action_description: str = None,
    start_time: str = None,
    end_time: str = None,
    enable: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a scheduled action. A scheduled action contains a schedule and an Amazon Redshift API action. For example, you can create a schedule of when to run the ResizeCluster API operation.

    Args:
        scheduled_action_name(str): The name of the scheduled action. The name must be unique within an account. For more information about this parameter, see ScheduledAction. .
        target_action(Dict): A JSON format string of the Amazon Redshift API operation with input parameters. For more information about this parameter, see ScheduledAction. .
        schedule(str): The schedule in at( ) or cron( ) format. For more information about this parameter, see ScheduledAction.
        iam_role(str): The IAM role to assume to run the target action. For more information about this parameter, see ScheduledAction. .
        scheduled_action_description(str, optional): The description of the scheduled action. . Defaults to None.
        start_time(str, optional): The start time in UTC of the scheduled action. Before this time, the scheduled action does not trigger. For more information about this parameter, see ScheduledAction. Defaults to None.
        end_time(str, optional): The end time in UTC of the scheduled action. After this time, the scheduled action does not trigger. For more information about this parameter, see ScheduledAction. . Defaults to None.
        enable(bool, optional): If true, the schedule is enabled. If false, the scheduled action does not trigger. For more information about state of the scheduled action, see ScheduledAction. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.scheduled_action.create(
                ctx,
                scheduled_action_name=value,
                target_action=value,
                schedule=value,
                iam_role=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.scheduled_action.create scheduled_action_name=value, target_action=value, schedule=value, iam_role=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="create_scheduled_action",
        op_kwargs={
            "ScheduledActionName": scheduled_action_name,
            "TargetAction": target_action,
            "Schedule": schedule,
            "IamRole": iam_role,
            "ScheduledActionDescription": scheduled_action_description,
            "StartTime": start_time,
            "EndTime": end_time,
            "Enable": enable,
        },
    )


async def delete(hub, ctx, scheduled_action_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a scheduled action.

    Args:
        scheduled_action_name(str): The name of the scheduled action to delete. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.scheduled_action.delete(
                ctx, scheduled_action_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.scheduled_action.delete scheduled_action_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="delete_scheduled_action",
        op_kwargs={"ScheduledActionName": scheduled_action_name},
    )


async def describe_all(
    hub,
    ctx,
    scheduled_action_name: str = None,
    target_action_type: str = None,
    start_time: str = None,
    end_time: str = None,
    active: bool = None,
    filters: List = None,
    marker: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes properties of scheduled actions.

    Args:
        scheduled_action_name(str, optional): The name of the scheduled action to retrieve. . Defaults to None.
        target_action_type(str, optional): The type of the scheduled actions to retrieve. . Defaults to None.
        start_time(str, optional): The start time in UTC of the scheduled actions to retrieve. Only active scheduled actions that have invocations after this time are retrieved. Defaults to None.
        end_time(str, optional): The end time in UTC of the scheduled action to retrieve. Only active scheduled actions that have invocations before this time are retrieved. Defaults to None.
        active(bool, optional): If true, retrieve only active scheduled actions. If false, retrieve only disabled scheduled actions. . Defaults to None.
        filters(List, optional): List of scheduled action filters. . Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeScheduledActions request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 100  Constraints: minimum 20, maximum 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.scheduled_action.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.scheduled_action.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_scheduled_actions",
        op_kwargs={
            "ScheduledActionName": scheduled_action_name,
            "TargetActionType": target_action_type,
            "StartTime": start_time,
            "EndTime": end_time,
            "Active": active,
            "Filters": filters,
            "Marker": marker,
            "MaxRecords": max_records,
        },
    )


async def modify(
    hub,
    ctx,
    scheduled_action_name: str,
    target_action: Dict = None,
    schedule: str = None,
    iam_role: str = None,
    scheduled_action_description: str = None,
    start_time: str = None,
    end_time: str = None,
    enable: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies a scheduled action.

    Args:
        scheduled_action_name(str): The name of the scheduled action to modify. .
        target_action(Dict, optional): A modified JSON format of the scheduled action. For more information about this parameter, see ScheduledAction. . Defaults to None.
        schedule(str, optional): A modified schedule in either at( ) or cron( ) format. For more information about this parameter, see ScheduledAction. Defaults to None.
        iam_role(str, optional): A different IAM role to assume to run the target action. For more information about this parameter, see ScheduledAction. Defaults to None.
        scheduled_action_description(str, optional): A modified description of the scheduled action. . Defaults to None.
        start_time(str, optional): A modified start time of the scheduled action. For more information about this parameter, see ScheduledAction. . Defaults to None.
        end_time(str, optional): A modified end time of the scheduled action. For more information about this parameter, see ScheduledAction. . Defaults to None.
        enable(bool, optional): A modified enable flag of the scheduled action. If true, the scheduled action is active. If false, the scheduled action is disabled. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.scheduled_action.modify(
                ctx, scheduled_action_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.scheduled_action.modify scheduled_action_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="modify_scheduled_action",
        op_kwargs={
            "ScheduledActionName": scheduled_action_name,
            "TargetAction": target_action,
            "Schedule": schedule,
            "IamRole": iam_role,
            "ScheduledActionDescription": scheduled_action_description,
            "StartTime": start_time,
            "EndTime": end_time,
            "Enable": enable,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, model_package_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a model group resource policy.

    Args:
        model_package_group_name(str): The name of the model group for which to delete the policy.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.package.group.policy.delete(
                ctx, model_package_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.package.group.policy.delete model_package_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_model_package_group_policy",
        op_kwargs={"ModelPackageGroupName": model_package_group_name},
    )


async def get(hub, ctx, model_package_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a resource policy that manages access for a model group. For information about resource policies, see Identity-based policies and resource-based policies in the Amazon Web Services Identity and Access Management User Guide..

    Args:
        model_package_group_name(str): The name of the model group for which to get the resource policy.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.package.group.policy.get(
                ctx, model_package_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.package.group.policy.get model_package_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="get_model_package_group_policy",
        op_kwargs={"ModelPackageGroupName": model_package_group_name},
    )


async def put(hub, ctx, model_package_group_name: str, resource_policy: str) -> Dict:
    r"""
    **Autogenerated function**

    Adds a resouce policy to control access to a model group. For information about resoure policies, see Identity-based policies and resource-based policies in the Amazon Web Services Identity and Access Management User Guide..

    Args:
        model_package_group_name(str): The name of the model group to add a resource policy to.
        resource_policy(str): The resource policy for the model group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.package.group.policy.put(
                ctx, model_package_group_name=value, resource_policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.package.group.policy.put model_package_group_name=value, resource_policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="put_model_package_group_policy",
        op_kwargs={
            "ModelPackageGroupName": model_package_group_name,
            "ResourcePolicy": resource_policy,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    hit_id: str,
    policy_levels: List = None,
    retrieve_actions: bool = None,
    retrieve_results: bool = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The ListReviewPolicyResultsForHIT operation retrieves the computed results and the actions taken in the course of executing your Review Policies for a given HIT. For information about how to specify Review Policies when you call CreateHIT, see Review Policies. The ListReviewPolicyResultsForHIT operation can return results for both Assignment-level and HIT-level review results.

    Args:
        hit_id(str): The unique identifier of the HIT to retrieve review results for.
        policy_levels(List, optional):  The Policy Level(s) to retrieve review results for - HIT or Assignment. If omitted, the default behavior is to retrieve all data for both policy levels. For a list of all the described policies, see Review Policies. . Defaults to None.
        retrieve_actions(bool, optional):  Specify if the operation should retrieve a list of the actions taken executing the Review Policies and their outcomes. . Defaults to None.
        retrieve_results(bool, optional):  Specify if the operation should retrieve a list of the results computed by the Review Policies. . Defaults to None.
        next_token(str, optional): Pagination token. Defaults to None.
        max_results(int, optional): Limit the number of results returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.review.policy_result_for_hit.list(ctx, hit_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.review.policy_result_for_hit.list hit_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="list_review_policy_results_for_hit",
        op_kwargs={
            "HITId": hit_id,
            "PolicyLevels": policy_levels,
            "RetrieveActions": retrieve_actions,
            "RetrieveResults": retrieve_results,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def query(
    hub,
    ctx,
    index_id: str,
    query_text: str,
    attribute_filter: Dict = None,
    facets: List = None,
    requested_document_attributes: List = None,
    query_result_type_filter: str = None,
    document_relevance_override_configurations: List = None,
    page_number: int = None,
    page_size: int = None,
    sorting_configuration: Dict = None,
    user_context: Dict = None,
    visitor_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches an active index. Use this API to search your documents using query. The Query operation enables to do faceted search and to filter results based on document attributes. It also enables you to provide user context that Amazon Kendra uses to enforce document access control in the search results.  Amazon Kendra searches your index for text content and question and answer (FAQ) content. By default the response contains three types of results.   Relevant passages   Matching FAQs   Relevant documents   You can specify that the query return only one type of result using the QueryResultTypeConfig parameter. Each query returns the 100 most relevant results.

    Args:
        index_id(str): The unique identifier of the index to search. The identifier is returned in the response from the CreateIndex operation.
        query_text(str): The text to search for.
        attribute_filter(Dict, optional): Enables filtered searches based on document attributes. You can only provide one attribute filter; however, the AndAllFilters, NotFilter, and OrAllFilters parameters contain a list of other filters. The AttributeFilter parameter enables you to create a set of filtering rules that a document must satisfy to be included in the query results. Defaults to None.
        facets(List, optional): An array of documents attributes. Amazon Kendra returns a count for each attribute key specified. You can use this information to help narrow the search for your user. Defaults to None.
        requested_document_attributes(List, optional): An array of document attributes to include in the response. No other document attributes are included in the response. By default all document attributes are included in the response. . Defaults to None.
        query_result_type_filter(str, optional): Sets the type of query. Only results for the specified query type are returned. Defaults to None.
        document_relevance_override_configurations(List, optional): Overrides relevance tuning configurations of fields or attributes set at the index level. If you use this API to override the relevance tuning configured at the index level, but there is no relevance tuning configured at the index level, then Amazon Kendra does not apply any relevance tuning. If there is relevance tuning configured at the index level, but you do not use this API to override any relevance tuning in the index, then Amazon Kendra uses the relevance tuning that is configured at the index level. If there is relevance tuning configured for fields at the index level, but you use this API to override only some of these fields, then for the fields you did not override, the importance is set to 1. Defaults to None.
        page_number(int, optional): Query results are returned in pages the size of the PageSize parameter. By default, Amazon Kendra returns the first page of results. Use this parameter to get result pages after the first one. Defaults to None.
        page_size(int, optional): Sets the number of results that are returned in each page of results. The default page size is 10. The maximum number of results returned is 100. If you ask for more than 100 results, only 100 are returned. Defaults to None.
        sorting_configuration(Dict, optional): Provides information that determines how the results of the query are sorted. You can set the field that Amazon Kendra should sort the results on, and specify whether the results should be sorted in ascending or descending order. In the case of ties in sorting the results, the results are sorted by relevance. If you don't provide sorting configuration, the results are sorted by the relevance that Amazon Kendra determines for the result. Defaults to None.
        user_context(Dict, optional): The user context token. Defaults to None.
        visitor_id(str, optional): Provides an identifier for a specific user. The VisitorId should be a unique identifier, such as a GUID. Don't use personally identifiable information, such as the user's email address, as the VisitorId. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.init.query(ctx, index_id=value, query_text=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.init.query index_id=value, query_text=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="query",
        op_kwargs={
            "IndexId": index_id,
            "QueryText": query_text,
            "AttributeFilter": attribute_filter,
            "Facets": facets,
            "RequestedDocumentAttributes": requested_document_attributes,
            "QueryResultTypeFilter": query_result_type_filter,
            "DocumentRelevanceOverrideConfigurations": document_relevance_override_configurations,
            "PageNumber": page_number,
            "PageSize": page_size,
            "SortingConfiguration": sorting_configuration,
            "UserContext": user_context,
            "VisitorId": visitor_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Creates a usage report subscription. Usage reports are generated daily.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.usage_report_subscription.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.usage_report_subscription.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="create_usage_report_subscription",
        op_kwargs={},
    )


async def delete(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Disables usage report generation.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.usage_report_subscription.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.usage_report_subscription.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="delete_usage_report_subscription",
        op_kwargs={},
    )


async def describe_all(
    hub, ctx, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list that describes one or more usage report subscriptions.

    Args:
        max_results(int, optional): The maximum size of each page of results. Defaults to None.
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.usage_report_subscription.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.usage_report_subscription.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="describe_usage_report_subscriptions",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create_multiple(hub, ctx, account_details: List) -> Dict:
    r"""
    **Autogenerated function**

    Creates a member association in Security Hub between the specified accounts and the account used to make the request, which is the administrator account. If you are integrated with Organizations, then the administrator account is designated by the organization management account.  CreateMembers is always used to add accounts that are not organization members. For accounts that are managed using Organizations, CreateMembers is only used in the following cases:   Security Hub is not configured to automatically add new organization accounts.   The account was disassociated or deleted in Security Hub.   This action can only be used by an account that has Security Hub enabled. To enable Security Hub, you can use the EnableSecurityHub operation. For accounts that are not organization members, you create the account association and then send an invitation to the member account. To send the invitation, you use the InviteMembers operation. If the account owner accepts the invitation, the account becomes a member account in Security Hub. Accounts that are managed using Organizations do not receive an invitation. They automatically become a member account in Security Hub, and Security Hub is automatically enabled for those accounts. Note that Security Hub cannot be enabled automatically for the organization management account. The organization management account must enable Security Hub before the administrator account enables it as a member account. A permissions policy is added that permits the administrator account to view the findings generated in the member account. When Security Hub is enabled in a member account, the member account findings are also visible to the administrator account.  To remove the association between the administrator and member accounts, use the DisassociateFromMasterAccount or DisassociateMembers operation.

    Args:
        account_details(List): The list of accounts to associate with the Security Hub administrator account. For each account, the list includes the account ID and optionally the email address.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.member.create_multiple(ctx, account_details=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.member.create_multiple account_details=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="create_members",
        op_kwargs={"AccountDetails": account_details},
    )


async def delete_multiple(hub, ctx, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified member accounts from Security Hub. Can be used to delete member accounts that belong to an organization as well as member accounts that were invited manually.

    Args:
        account_ids(List): The list of account IDs for the member accounts to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.member.delete_multiple(ctx, account_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.member.delete_multiple account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="delete_members",
        op_kwargs={"AccountIds": account_ids},
    )


async def disassociate(hub, ctx, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates the specified member accounts from the associated administrator account. Can be used to disassociate both accounts that are managed using Organizations and accounts that were invited manually.

    Args:
        account_ids(List): The account IDs of the member accounts to disassociate from the administrator account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.member.disassociate(ctx, account_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.member.disassociate account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="disassociate_members",
        op_kwargs={"AccountIds": account_ids},
    )


async def get_all(hub, ctx, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns the details for the Security Hub member accounts for the specified account IDs. An administrator account can be either the delegated Security Hub administrator account for an organization or an administrator account that enabled Security Hub manually. The results include both member accounts that are managed using Organizations and accounts that were invited manually.

    Args:
        account_ids(List): The list of account IDs for the Security Hub member accounts to return the details for. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.member.get_all(ctx, account_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.member.get_all account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="get_members",
        op_kwargs={"AccountIds": account_ids},
    )


async def invite(hub, ctx, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Invites other Amazon Web Services accounts to become member accounts for the Security Hub administrator account that the invitation is sent from. This operation is only used to invite accounts that do not belong to an organization. Organization accounts do not receive invitations. Before you can use this action to invite a member, you must first use the CreateMembers action to create the member account in Security Hub. When the account owner enables Security Hub and accepts the invitation to become a member account, the administrator account can view the findings generated from the member account.

    Args:
        account_ids(List): The list of account IDs of the Amazon Web Services accounts to invite to Security Hub as members. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.member.invite(ctx, account_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.member.invite account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="invite_members",
        op_kwargs={"AccountIds": account_ids},
    )


async def list_all(
    hub,
    ctx,
    only_associated: bool = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists details about all member accounts for the current Security Hub administrator account. The results include both member accounts that belong to an organization and member accounts that were invited manually.

    Args:
        only_associated(bool, optional): Specifies which member accounts to include in the response based on their relationship status with the administrator account. The default value is TRUE. If OnlyAssociated is set to TRUE, the response includes member accounts whose relationship status with the administrator account is set to ENABLED. If OnlyAssociated is set to FALSE, the response includes all existing member accounts. . Defaults to None.
        max_results(int, optional): The maximum number of items to return in the response. . Defaults to None.
        next_token(str, optional): The token that is required for pagination. On your first call to the ListMembers operation, set the value of this parameter to NULL. For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.member.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.member.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="list_members",
        op_kwargs={
            "OnlyAssociated": only_associated,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def get_all(hub, ctx, endpoint_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the endpoint attributes for a device on one of the supported push notification services, such as GCM (Firebase Cloud Messaging) and APNS. For more information, see Using Amazon SNS Mobile Push Notifications.

    Args:
        endpoint_arn(str): EndpointArn for GetEndpointAttributes input.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.endpoint.attribute.get_all(ctx, endpoint_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.endpoint.attribute.get_all endpoint_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="get_endpoint_attributes",
        op_kwargs={"EndpointArn": endpoint_arn},
    )


async def set_(hub, ctx, endpoint_arn: str, attributes: Dict) -> None:
    r"""
    **Autogenerated function**

    Sets the attributes for an endpoint for a device on one of the supported push notification services, such as GCM (Firebase Cloud Messaging) and APNS. For more information, see Using Amazon SNS Mobile Push Notifications.

    Args:
        endpoint_arn(str): EndpointArn used for SetEndpointAttributes action.
        attributes(Dict): A map of the endpoint attributes. Attributes in this map include the following:    CustomUserData – arbitrary user data to associate with the endpoint. Amazon SNS does not use this data. The data must be in UTF-8 format and less than 2KB.    Enabled – flag that enables/disables delivery to the endpoint. Amazon SNS will set this to false when a notification service indicates to Amazon SNS that the endpoint is invalid. Users can set it back to true, typically after updating Token.    Token – device token, also referred to as a registration id, for an app and mobile device. This is returned from the notification service when an app and mobile device are registered with the notification service.  .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.endpoint.attribute.set(
                ctx, endpoint_arn=value, attributes=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.endpoint.attribute.set endpoint_arn=value, attributes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="set_endpoint_attributes",
        op_kwargs={"EndpointArn": endpoint_arn, "Attributes": attributes},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    routing_strategy: Dict,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an alias for a fleet. In most situations, you can use an alias ID in place of a fleet ID. An alias provides a level of abstraction for a fleet that is useful when redirecting player traffic from one fleet to another, such as when updating your game build.  Amazon GameLift supports two types of routing strategies for aliases: simple and terminal. A simple alias points to an active fleet. A terminal alias is used to display messaging or link to a URL instead of routing players to an active fleet. For example, you might use a terminal alias when a game version is no longer supported and you want to direct players to an upgrade site.  To create a fleet alias, specify an alias name, routing strategy, and optional description. Each simple alias can point to only one fleet, but a fleet can have multiple aliases. If successful, a new alias record is returned, including an alias ID and an ARN. You can reassign an alias to another fleet by calling UpdateAlias.  Related actions   CreateAlias | ListAliases | DescribeAlias | UpdateAlias | DeleteAlias | ResolveAlias | All APIs by task

    Args:
        name(str): A descriptive label that is associated with an alias. Alias names do not need to be unique.
        description(str, optional): A human-readable description of the alias. Defaults to None.
        routing_strategy(Dict): The routing configuration, including routing type and fleet target, for the alias. .
        tags(List, optional): A list of labels to assign to the new alias resource. Tags are developer-defined key-value pairs. Tagging AWS resources are useful for resource management, access management and cost allocation. For more information, see  Tagging AWS Resources in the AWS General Reference. Once the resource is created, you can use TagResource, UntagResource, and ListTagsForResource to add, remove, and view tags. The maximum tag limit may be lower than stated. See the AWS General Reference for actual tagging limits. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.alias.create(ctx, name=value, routing_strategy=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.alias.create name=value, routing_strategy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="create_alias",
        op_kwargs={
            "Name": name,
            "Description": description,
            "RoutingStrategy": routing_strategy,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, alias_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an alias. This operation removes all record of the alias. Game clients attempting to access a server process using the deleted alias receive an error. To delete an alias, specify the alias ID to be deleted.  Related actions   CreateAlias | ListAliases | DescribeAlias | UpdateAlias | DeleteAlias | ResolveAlias | All APIs by task

    Args:
        alias_id(str): A unique identifier of the alias that you want to delete. You can use either the alias ID or ARN value.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.alias.delete(ctx, alias_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.alias.delete alias_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="delete_alias",
        op_kwargs={"AliasId": alias_id},
    )


async def describe(hub, ctx, alias_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves properties for an alias. This operation returns all alias metadata and settings. To get an alias's target fleet ID only, use ResolveAlias.  To get alias properties, specify the alias ID. If successful, the requested alias record is returned.  Related actions   CreateAlias | ListAliases | DescribeAlias | UpdateAlias | DeleteAlias | ResolveAlias | All APIs by task

    Args:
        alias_id(str): The unique identifier for the fleet alias that you want to retrieve. You can use either the alias ID or ARN value. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.alias.describe(ctx, alias_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.alias.describe alias_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_alias",
        op_kwargs={"AliasId": alias_id},
    )


async def list_all(
    hub,
    ctx,
    routing_strategy_type: str = None,
    name: str = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves all aliases for this AWS account. You can filter the result set by alias name and/or routing strategy type. Use the pagination parameters to retrieve results in sequential pages.  Returned aliases are not listed in any particular order.   Related actions   CreateAlias | ListAliases | DescribeAlias | UpdateAlias | DeleteAlias | ResolveAlias | All APIs by task

    Args:
        routing_strategy_type(str, optional): The routing type to filter results on. Use this parameter to retrieve only aliases with a certain routing type. To retrieve all aliases, leave this parameter empty. Possible routing types include the following:    SIMPLE -- The alias resolves to one specific fleet. Use this type when routing to active fleets.    TERMINAL -- The alias does not resolve to a fleet but instead can be used to display a message to the user. A terminal alias throws a TerminalRoutingStrategyException with the RoutingStrategy message embedded.  . Defaults to None.
        name(str, optional): A descriptive label that is associated with an alias. Alias names do not need to be unique. Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.alias.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.alias.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="list_aliases",
        op_kwargs={
            "RoutingStrategyType": routing_strategy_type,
            "Name": name,
            "Limit": limit,
            "NextToken": next_token,
        },
    )


async def resolve(hub, ctx, alias_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the fleet ID that an alias is currently pointing to.  Related actions   CreateAlias | ListAliases | DescribeAlias | UpdateAlias | DeleteAlias | ResolveAlias | All APIs by task

    Args:
        alias_id(str): The unique identifier of the alias that you want to retrieve a fleet ID for. You can use either the alias ID or ARN value.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.alias.resolve(ctx, alias_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.alias.resolve alias_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="resolve_alias",
        op_kwargs={"AliasId": alias_id},
    )


async def update(
    hub,
    ctx,
    alias_id: str,
    name: str = None,
    description: str = None,
    routing_strategy: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates properties for an alias. To update properties, specify the alias ID to be updated and provide the information to be changed. To reassign an alias to another fleet, provide an updated routing strategy. If successful, the updated alias record is returned.  Related actions   CreateAlias | ListAliases | DescribeAlias | UpdateAlias | DeleteAlias | ResolveAlias | All APIs by task

    Args:
        alias_id(str): A unique identifier for the alias that you want to update. You can use either the alias ID or ARN value.
        name(str, optional): A descriptive label that is associated with an alias. Alias names do not need to be unique. Defaults to None.
        description(str, optional): A human-readable description of the alias. Defaults to None.
        routing_strategy(Dict, optional): The routing configuration, including routing type and fleet target, for the alias. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.alias.update(ctx, alias_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.alias.update alias_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="update_alias",
        op_kwargs={
            "AliasId": alias_id,
            "Name": name,
            "Description": description,
            "RoutingStrategy": routing_strategy,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def clone(
    hub,
    ctx,
    source_stack_id: str,
    service_role_arn: str,
    name: str = None,
    region: str = None,
    vpc_id: str = None,
    attributes: Dict = None,
    default_instance_profile_arn: str = None,
    default_os: str = None,
    hostname_theme: str = None,
    default_availability_zone: str = None,
    default_subnet_id: str = None,
    custom_json: str = None,
    configuration_manager: Dict = None,
    chef_configuration: Dict = None,
    use_custom_cookbooks: bool = None,
    use_opsworks_security_groups: bool = None,
    custom_cookbooks_source: Dict = None,
    default_ssh_key_name: str = None,
    clone_permissions: bool = None,
    clone_app_ids: List = None,
    default_root_device_type: str = None,
    agent_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a clone of a specified stack. For more information, see Clone a Stack. By default, all parameters are set to the values used by the parent stack.  Required Permissions: To use this action, an IAM user must have an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        source_stack_id(str): The source stack ID.
        name(str, optional): The cloned stack name. Defaults to None.
        region(str, optional): The cloned stack AWS region, such as "ap-northeast-2". For more information about AWS regions, see Regions and Endpoints. Defaults to None.
        vpc_id(str, optional): The ID of the VPC that the cloned stack is to be launched into. It must be in the specified region. All instances are launched into this VPC, and you cannot change the ID later.   If your account supports EC2 Classic, the default value is no VPC.   If your account does not support EC2 Classic, the default value is the default VPC for the specified region.   If the VPC ID corresponds to a default VPC and you have specified either the DefaultAvailabilityZone or the DefaultSubnetId parameter only, AWS OpsWorks Stacks infers the value of the other parameter. If you specify neither parameter, AWS OpsWorks Stacks sets these parameters to the first valid Availability Zone for the specified region and the corresponding default VPC subnet ID, respectively.  If you specify a nondefault VPC ID, note the following:   It must belong to a VPC in your account that is in the specified region.   You must specify a value for DefaultSubnetId.   For more information about how to use AWS OpsWorks Stacks with a VPC, see Running a Stack in a VPC. For more information about default VPC and EC2 Classic, see Supported Platforms. . Defaults to None.
        attributes(Dict, optional): A list of stack attributes and values as key/value pairs to be added to the cloned stack. Defaults to None.
        service_role_arn(str): The stack AWS Identity and Access Management (IAM) role, which allows AWS OpsWorks Stacks to work with AWS resources on your behalf. You must set this parameter to the Amazon Resource Name (ARN) for an existing IAM role. If you create a stack by using the AWS OpsWorks Stacks console, it creates the role for you. You can obtain an existing stack's IAM ARN programmatically by calling DescribePermissions. For more information about IAM ARNs, see Using Identifiers.  You must set this parameter to a valid service role ARN or the action will fail; there is no default value. You can specify the source stack's service role ARN, if you prefer, but you must do so explicitly. .
        default_instance_profile_arn(str, optional): The Amazon Resource Name (ARN) of an IAM profile that is the default profile for all of the stack's EC2 instances. For more information about IAM ARNs, see Using Identifiers. Defaults to None.
        default_os(str, optional): The stack's operating system, which must be set to one of the following.   A supported Linux operating system: An Amazon Linux version, such as Amazon Linux 2018.03, Amazon Linux 2017.09, Amazon Linux 2017.03, Amazon Linux 2016.09, Amazon Linux 2016.03, Amazon Linux 2015.09, or Amazon Linux 2015.03.   A supported Ubuntu operating system, such as Ubuntu 16.04 LTS, Ubuntu 14.04 LTS, or Ubuntu 12.04 LTS.    CentOS Linux 7     Red Hat Enterprise Linux 7     Microsoft Windows Server 2012 R2 Base, Microsoft Windows Server 2012 R2 with SQL Server Express, Microsoft Windows Server 2012 R2 with SQL Server Standard, or Microsoft Windows Server 2012 R2 with SQL Server Web.   A custom AMI: Custom. You specify the custom AMI you want to use when you create instances. For more information about how to use custom AMIs with OpsWorks, see Using Custom AMIs.   The default option is the parent stack's operating system. For more information about supported operating systems, see AWS OpsWorks Stacks Operating Systems.  You can specify a different Linux operating system for the cloned stack, but you cannot change from Linux to Windows or Windows to Linux. . Defaults to None.
        hostname_theme(str, optional): The stack's host name theme, with spaces are replaced by underscores. The theme is used to generate host names for the stack's instances. By default, HostnameTheme is set to Layer_Dependent, which creates host names by appending integers to the layer's short name. The other themes are:    Baked_Goods     Clouds     Europe_Cities     Fruits     Greek_Deities_and_Titans     Legendary_creatures_from_Japan     Planets_and_Moons     Roman_Deities     Scottish_Islands     US_Cities     Wild_Cats    To obtain a generated host name, call GetHostNameSuggestion, which returns a host name based on the current theme. Defaults to None.
        default_availability_zone(str, optional): The cloned stack's default Availability Zone, which must be in the specified region. For more information, see Regions and Endpoints. If you also specify a value for DefaultSubnetId, the subnet must be in the same zone. For more information, see the VpcId parameter description. . Defaults to None.
        default_subnet_id(str, optional): The stack's default VPC subnet ID. This parameter is required if you specify a value for the VpcId parameter. All instances are launched into this subnet unless you specify otherwise when you create the instance. If you also specify a value for DefaultAvailabilityZone, the subnet must be in that zone. For information on default values and when this parameter is required, see the VpcId parameter description. . Defaults to None.
        custom_json(str, optional): A string that contains user-defined, custom JSON. It is used to override the corresponding default stack configuration JSON values. The string should be in the following format:  "{\"key1\": \"value1\", \"key2\": \"value2\",...}"  For more information about custom JSON, see Use Custom JSON to Modify the Stack Configuration Attributes . Defaults to None.
        configuration_manager(Dict, optional): The configuration manager. When you clone a stack we recommend that you use the configuration manager to specify the Chef version: 12, 11.10, or 11.4 for Linux stacks, or 12.2 for Windows stacks. The default value for Linux stacks is currently 12. Defaults to None.
        chef_configuration(Dict, optional): A ChefConfiguration object that specifies whether to enable Berkshelf and the Berkshelf version on Chef 11.10 stacks. For more information, see Create a New Stack. Defaults to None.
        use_custom_cookbooks(bool, optional): Whether to use custom cookbooks. Defaults to None.
        use_opsworks_security_groups(bool, optional): Whether to associate the AWS OpsWorks Stacks built-in security groups with the stack's layers. AWS OpsWorks Stacks provides a standard set of built-in security groups, one for each layer, which are associated with layers by default. With UseOpsworksSecurityGroups you can instead provide your own custom security groups. UseOpsworksSecurityGroups has the following settings:    True - AWS OpsWorks Stacks automatically associates the appropriate built-in security group with each layer (default setting). You can associate additional security groups with a layer after you create it but you cannot delete the built-in security group.   False - AWS OpsWorks Stacks does not associate built-in security groups with layers. You must create appropriate Amazon Elastic Compute Cloud (Amazon EC2) security groups and associate a security group with each layer that you create. However, you can still manually associate a built-in security group with a layer on creation; custom security groups are required only for those layers that need custom settings.   For more information, see Create a New Stack. Defaults to None.
        custom_cookbooks_source(Dict, optional): Contains the information required to retrieve an app or cookbook from a repository. For more information, see Adding Apps or Cookbooks and Recipes. Defaults to None.
        default_ssh_key_name(str, optional): A default Amazon EC2 key pair name. The default value is none. If you specify a key pair name, AWS OpsWorks installs the public key on the instance and you can use the private key with an SSH client to log in to the instance. For more information, see  Using SSH to Communicate with an Instance and  Managing SSH Access. You can override this setting by specifying a different key pair, or no key pair, when you  create an instance. . Defaults to None.
        clone_permissions(bool, optional): Whether to clone the source stack's permissions. Defaults to None.
        clone_app_ids(List, optional): A list of source stack app IDs to be included in the cloned stack. Defaults to None.
        default_root_device_type(str, optional): The default root device type. This value is used by default for all instances in the cloned stack, but you can override it when you create an instance. For more information, see Storage for the Root Device. Defaults to None.
        agent_version(str, optional): The default AWS OpsWorks Stacks agent version. You have the following options:   Auto-update - Set this parameter to LATEST. AWS OpsWorks Stacks automatically installs new agent versions on the stack's instances as soon as they are available.   Fixed version - Set this parameter to your preferred agent version. To update the agent version, you must edit the stack configuration and specify a new version. AWS OpsWorks Stacks then automatically installs that version on the stack's instances.   The default setting is LATEST. To specify an agent version, you must use the complete version number, not the abbreviated number shown on the console. For a list of available agent version numbers, call DescribeAgentVersions. AgentVersion cannot be set to Chef 12.2.  You can also specify an agent version when you create or update an instance, which overrides the stack's default setting. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.stack.init.clone(
                ctx, source_stack_id=value, service_role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.stack.init.clone source_stack_id=value, service_role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="clone_stack",
        op_kwargs={
            "SourceStackId": source_stack_id,
            "Name": name,
            "Region": region,
            "VpcId": vpc_id,
            "Attributes": attributes,
            "ServiceRoleArn": service_role_arn,
            "DefaultInstanceProfileArn": default_instance_profile_arn,
            "DefaultOs": default_os,
            "HostnameTheme": hostname_theme,
            "DefaultAvailabilityZone": default_availability_zone,
            "DefaultSubnetId": default_subnet_id,
            "CustomJson": custom_json,
            "ConfigurationManager": configuration_manager,
            "ChefConfiguration": chef_configuration,
            "UseCustomCookbooks": use_custom_cookbooks,
            "UseOpsworksSecurityGroups": use_opsworks_security_groups,
            "CustomCookbooksSource": custom_cookbooks_source,
            "DefaultSshKeyName": default_ssh_key_name,
            "ClonePermissions": clone_permissions,
            "CloneAppIds": clone_app_ids,
            "DefaultRootDeviceType": default_root_device_type,
            "AgentVersion": agent_version,
        },
    )


async def create(
    hub,
    ctx,
    name: str,
    region: str,
    service_role_arn: str,
    default_instance_profile_arn: str,
    vpc_id: str = None,
    attributes: Dict = None,
    default_os: str = None,
    hostname_theme: str = None,
    default_availability_zone: str = None,
    default_subnet_id: str = None,
    custom_json: str = None,
    configuration_manager: Dict = None,
    chef_configuration: Dict = None,
    use_custom_cookbooks: bool = None,
    use_opsworks_security_groups: bool = None,
    custom_cookbooks_source: Dict = None,
    default_ssh_key_name: str = None,
    default_root_device_type: str = None,
    agent_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new stack. For more information, see Create a New Stack.  Required Permissions: To use this action, an IAM user must have an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        name(str): The stack name.
        region(str): The stack's AWS region, such as ap-south-1. For more information about Amazon regions, see Regions and Endpoints.  In the AWS CLI, this API maps to the --stack-region parameter. If the --stack-region parameter and the AWS CLI common parameter --region are set to the same value, the stack uses a regional endpoint. If the --stack-region parameter is not set, but the AWS CLI --region parameter is, this also results in a stack with a regional endpoint. However, if the --region parameter is set to us-east-1, and the --stack-region parameter is set to one of the following, then the stack uses a legacy or classic region: us-west-1, us-west-2, sa-east-1, eu-central-1, eu-west-1, ap-northeast-1, ap-southeast-1, ap-southeast-2. In this case, the actual API endpoint of the stack is in us-east-1. Only the preceding regions are supported as classic regions in the us-east-1 API endpoint. Because it is a best practice to choose the regional endpoint that is closest to where you manage AWS, we recommend that you use regional endpoints for new stacks. The AWS CLI common --region parameter always specifies a regional API endpoint; it cannot be used to specify a classic AWS OpsWorks Stacks region. .
        vpc_id(str, optional): The ID of the VPC that the stack is to be launched into. The VPC must be in the stack's region. All instances are launched into this VPC. You cannot change the ID later.   If your account supports EC2-Classic, the default value is no VPC.   If your account does not support EC2-Classic, the default value is the default VPC for the specified region.   If the VPC ID corresponds to a default VPC and you have specified either the DefaultAvailabilityZone or the DefaultSubnetId parameter only, AWS OpsWorks Stacks infers the value of the other parameter. If you specify neither parameter, AWS OpsWorks Stacks sets these parameters to the first valid Availability Zone for the specified region and the corresponding default VPC subnet ID, respectively. If you specify a nondefault VPC ID, note the following:   It must belong to a VPC in your account that is in the specified region.   You must specify a value for DefaultSubnetId.   For more information about how to use AWS OpsWorks Stacks with a VPC, see Running a Stack in a VPC. For more information about default VPC and EC2-Classic, see Supported Platforms. . Defaults to None.
        attributes(Dict, optional): One or more user-defined key-value pairs to be added to the stack attributes. Defaults to None.
        service_role_arn(str): The stack's AWS Identity and Access Management (IAM) role, which allows AWS OpsWorks Stacks to work with AWS resources on your behalf. You must set this parameter to the Amazon Resource Name (ARN) for an existing IAM role. For more information about IAM ARNs, see Using Identifiers.
        default_instance_profile_arn(str): The Amazon Resource Name (ARN) of an IAM profile that is the default profile for all of the stack's EC2 instances. For more information about IAM ARNs, see Using Identifiers.
        default_os(str, optional): The stack's default operating system, which is installed on every instance unless you specify a different operating system when you create the instance. You can specify one of the following.   A supported Linux operating system: An Amazon Linux version, such as Amazon Linux 2018.03, Amazon Linux 2017.09, Amazon Linux 2017.03, Amazon Linux 2016.09, Amazon Linux 2016.03, Amazon Linux 2015.09, or Amazon Linux 2015.03.   A supported Ubuntu operating system, such as Ubuntu 16.04 LTS, Ubuntu 14.04 LTS, or Ubuntu 12.04 LTS.    CentOS Linux 7     Red Hat Enterprise Linux 7    A supported Windows operating system, such as Microsoft Windows Server 2012 R2 Base, Microsoft Windows Server 2012 R2 with SQL Server Express, Microsoft Windows Server 2012 R2 with SQL Server Standard, or Microsoft Windows Server 2012 R2 with SQL Server Web.   A custom AMI: Custom. You specify the custom AMI you want to use when you create instances. For more information, see  Using Custom AMIs.   The default option is the current Amazon Linux version. For more information about supported operating systems, see AWS OpsWorks Stacks Operating Systems. Defaults to None.
        hostname_theme(str, optional): The stack's host name theme, with spaces replaced by underscores. The theme is used to generate host names for the stack's instances. By default, HostnameTheme is set to Layer_Dependent, which creates host names by appending integers to the layer's short name. The other themes are:    Baked_Goods     Clouds     Europe_Cities     Fruits     Greek_Deities_and_Titans     Legendary_creatures_from_Japan     Planets_and_Moons     Roman_Deities     Scottish_Islands     US_Cities     Wild_Cats    To obtain a generated host name, call GetHostNameSuggestion, which returns a host name based on the current theme. Defaults to None.
        default_availability_zone(str, optional): The stack's default Availability Zone, which must be in the specified region. For more information, see Regions and Endpoints. If you also specify a value for DefaultSubnetId, the subnet must be in the same zone. For more information, see the VpcId parameter description. . Defaults to None.
        default_subnet_id(str, optional): The stack's default VPC subnet ID. This parameter is required if you specify a value for the VpcId parameter. All instances are launched into this subnet unless you specify otherwise when you create the instance. If you also specify a value for DefaultAvailabilityZone, the subnet must be in that zone. For information on default values and when this parameter is required, see the VpcId parameter description. . Defaults to None.
        custom_json(str, optional): A string that contains user-defined, custom JSON. It can be used to override the corresponding default stack configuration attribute values or to pass data to recipes. The string should be in the following format:  "{\"key1\": \"value1\", \"key2\": \"value2\",...}"  For more information about custom JSON, see Use Custom JSON to Modify the Stack Configuration Attributes. Defaults to None.
        configuration_manager(Dict, optional): The configuration manager. When you create a stack we recommend that you use the configuration manager to specify the Chef version: 12, 11.10, or 11.4 for Linux stacks, or 12.2 for Windows stacks. The default value for Linux stacks is currently 12. Defaults to None.
        chef_configuration(Dict, optional): A ChefConfiguration object that specifies whether to enable Berkshelf and the Berkshelf version on Chef 11.10 stacks. For more information, see Create a New Stack. Defaults to None.
        use_custom_cookbooks(bool, optional): Whether the stack uses custom cookbooks. Defaults to None.
        use_opsworks_security_groups(bool, optional): Whether to associate the AWS OpsWorks Stacks built-in security groups with the stack's layers. AWS OpsWorks Stacks provides a standard set of built-in security groups, one for each layer, which are associated with layers by default. With UseOpsworksSecurityGroups you can instead provide your own custom security groups. UseOpsworksSecurityGroups has the following settings:    True - AWS OpsWorks Stacks automatically associates the appropriate built-in security group with each layer (default setting). You can associate additional security groups with a layer after you create it, but you cannot delete the built-in security group.   False - AWS OpsWorks Stacks does not associate built-in security groups with layers. You must create appropriate EC2 security groups and associate a security group with each layer that you create. However, you can still manually associate a built-in security group with a layer on creation; custom security groups are required only for those layers that need custom settings.   For more information, see Create a New Stack. Defaults to None.
        custom_cookbooks_source(Dict, optional): Contains the information required to retrieve an app or cookbook from a repository. For more information, see Adding Apps or Cookbooks and Recipes. Defaults to None.
        default_ssh_key_name(str, optional): A default Amazon EC2 key pair name. The default value is none. If you specify a key pair name, AWS OpsWorks installs the public key on the instance and you can use the private key with an SSH client to log in to the instance. For more information, see  Using SSH to Communicate with an Instance and  Managing SSH Access. You can override this setting by specifying a different key pair, or no key pair, when you  create an instance. . Defaults to None.
        default_root_device_type(str, optional): The default root device type. This value is the default for all instances in the stack, but you can override it when you create an instance. The default option is instance-store. For more information, see Storage for the Root Device. Defaults to None.
        agent_version(str, optional): The default AWS OpsWorks Stacks agent version. You have the following options:   Auto-update - Set this parameter to LATEST. AWS OpsWorks Stacks automatically installs new agent versions on the stack's instances as soon as they are available.   Fixed version - Set this parameter to your preferred agent version. To update the agent version, you must edit the stack configuration and specify a new version. AWS OpsWorks Stacks then automatically installs that version on the stack's instances.   The default setting is the most recent release of the agent. To specify an agent version, you must use the complete version number, not the abbreviated number shown on the console. For a list of available agent version numbers, call DescribeAgentVersions. AgentVersion cannot be set to Chef 12.2.  You can also specify an agent version when you create or update an instance, which overrides the stack's default setting. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.stack.init.create(
                ctx,
                name=value,
                region=value,
                service_role_arn=value,
                default_instance_profile_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.stack.init.create name=value, region=value, service_role_arn=value, default_instance_profile_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="create_stack",
        op_kwargs={
            "Name": name,
            "Region": region,
            "VpcId": vpc_id,
            "Attributes": attributes,
            "ServiceRoleArn": service_role_arn,
            "DefaultInstanceProfileArn": default_instance_profile_arn,
            "DefaultOs": default_os,
            "HostnameTheme": hostname_theme,
            "DefaultAvailabilityZone": default_availability_zone,
            "DefaultSubnetId": default_subnet_id,
            "CustomJson": custom_json,
            "ConfigurationManager": configuration_manager,
            "ChefConfiguration": chef_configuration,
            "UseCustomCookbooks": use_custom_cookbooks,
            "UseOpsworksSecurityGroups": use_opsworks_security_groups,
            "CustomCookbooksSource": custom_cookbooks_source,
            "DefaultSshKeyName": default_ssh_key_name,
            "DefaultRootDeviceType": default_root_device_type,
            "AgentVersion": agent_version,
        },
    )


async def delete(hub, ctx, stack_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a specified stack. You must first delete all instances, layers, and apps or deregister registered instances. For more information, see Shut Down a Stack.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        stack_id(str): The stack ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.stack.init.delete(ctx, stack_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.stack.init.delete stack_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="delete_stack",
        op_kwargs={"StackId": stack_id},
    )


async def describe_all(hub, ctx, stack_ids: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Requests a description of one or more stacks.  Required Permissions: To use this action, an IAM user must have a Show, Deploy, or Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        stack_ids(List, optional): An array of stack IDs that specify the stacks to be described. If you omit this parameter, DescribeStacks returns a description of every stack. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.stack.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.stack.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_stacks",
        op_kwargs={"StackIds": stack_ids},
    )


async def start(hub, ctx, stack_id: str) -> None:
    r"""
    **Autogenerated function**

    Starts a stack's instances.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        stack_id(str): The stack ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.stack.init.start(ctx, stack_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.stack.init.start stack_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="start_stack",
        op_kwargs={"StackId": stack_id},
    )


async def stop(hub, ctx, stack_id: str) -> None:
    r"""
    **Autogenerated function**

    Stops a specified stack.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        stack_id(str): The stack ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.stack.init.stop(ctx, stack_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.stack.init.stop stack_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="stop_stack",
        op_kwargs={"StackId": stack_id},
    )


async def update(
    hub,
    ctx,
    stack_id: str,
    name: str = None,
    attributes: Dict = None,
    service_role_arn: str = None,
    default_instance_profile_arn: str = None,
    default_os: str = None,
    hostname_theme: str = None,
    default_availability_zone: str = None,
    default_subnet_id: str = None,
    custom_json: str = None,
    configuration_manager: Dict = None,
    chef_configuration: Dict = None,
    use_custom_cookbooks: bool = None,
    custom_cookbooks_source: Dict = None,
    default_ssh_key_name: str = None,
    default_root_device_type: str = None,
    use_opsworks_security_groups: bool = None,
    agent_version: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates a specified stack.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        stack_id(str): The stack ID.
        name(str, optional): The stack's new name. Defaults to None.
        attributes(Dict, optional): One or more user-defined key-value pairs to be added to the stack attributes. Defaults to None.
        service_role_arn(str, optional): Do not use this parameter. You cannot update a stack's service role. Defaults to None.
        default_instance_profile_arn(str, optional): The ARN of an IAM profile that is the default profile for all of the stack's EC2 instances. For more information about IAM ARNs, see Using Identifiers. Defaults to None.
        default_os(str, optional): The stack's operating system, which must be set to one of the following:   A supported Linux operating system: An Amazon Linux version, such as Amazon Linux 2018.03, Amazon Linux 2017.09, Amazon Linux 2017.03, Amazon Linux 2016.09, Amazon Linux 2016.03, Amazon Linux 2015.09, or Amazon Linux 2015.03.   A supported Ubuntu operating system, such as Ubuntu 16.04 LTS, Ubuntu 14.04 LTS, or Ubuntu 12.04 LTS.    CentOS Linux 7     Red Hat Enterprise Linux 7    A supported Windows operating system, such as Microsoft Windows Server 2012 R2 Base, Microsoft Windows Server 2012 R2 with SQL Server Express, Microsoft Windows Server 2012 R2 with SQL Server Standard, or Microsoft Windows Server 2012 R2 with SQL Server Web.   A custom AMI: Custom. You specify the custom AMI you want to use when you create instances. For more information about how to use custom AMIs with OpsWorks, see Using Custom AMIs.   The default option is the stack's current operating system. For more information about supported operating systems, see AWS OpsWorks Stacks Operating Systems. Defaults to None.
        hostname_theme(str, optional): The stack's new host name theme, with spaces replaced by underscores. The theme is used to generate host names for the stack's instances. By default, HostnameTheme is set to Layer_Dependent, which creates host names by appending integers to the layer's short name. The other themes are:    Baked_Goods     Clouds     Europe_Cities     Fruits     Greek_Deities_and_Titans     Legendary_creatures_from_Japan     Planets_and_Moons     Roman_Deities     Scottish_Islands     US_Cities     Wild_Cats    To obtain a generated host name, call GetHostNameSuggestion, which returns a host name based on the current theme. Defaults to None.
        default_availability_zone(str, optional): The stack's default Availability Zone, which must be in the stack's region. For more information, see Regions and Endpoints. If you also specify a value for DefaultSubnetId, the subnet must be in the same zone. For more information, see CreateStack. . Defaults to None.
        default_subnet_id(str, optional): The stack's default VPC subnet ID. This parameter is required if you specify a value for the VpcId parameter. All instances are launched into this subnet unless you specify otherwise when you create the instance. If you also specify a value for DefaultAvailabilityZone, the subnet must be in that zone. For information on default values and when this parameter is required, see the VpcId parameter description. . Defaults to None.
        custom_json(str, optional): A string that contains user-defined, custom JSON. It can be used to override the corresponding default stack configuration JSON values or to pass data to recipes. The string should be in the following format:  "{\"key1\": \"value1\", \"key2\": \"value2\",...}"  For more information about custom JSON, see Use Custom JSON to Modify the Stack Configuration Attributes. Defaults to None.
        configuration_manager(Dict, optional): The configuration manager. When you update a stack, we recommend that you use the configuration manager to specify the Chef version: 12, 11.10, or 11.4 for Linux stacks, or 12.2 for Windows stacks. The default value for Linux stacks is currently 12. Defaults to None.
        chef_configuration(Dict, optional): A ChefConfiguration object that specifies whether to enable Berkshelf and the Berkshelf version on Chef 11.10 stacks. For more information, see Create a New Stack. Defaults to None.
        use_custom_cookbooks(bool, optional): Whether the stack uses custom cookbooks. Defaults to None.
        custom_cookbooks_source(Dict, optional): Contains the information required to retrieve an app or cookbook from a repository. For more information, see Adding Apps or Cookbooks and Recipes. Defaults to None.
        default_ssh_key_name(str, optional): A default Amazon EC2 key-pair name. The default value is none. If you specify a key-pair name, AWS OpsWorks Stacks installs the public key on the instance and you can use the private key with an SSH client to log in to the instance. For more information, see  Using SSH to Communicate with an Instance and  Managing SSH Access. You can override this setting by specifying a different key pair, or no key pair, when you  create an instance. . Defaults to None.
        default_root_device_type(str, optional): The default root device type. This value is used by default for all instances in the stack, but you can override it when you create an instance. For more information, see Storage for the Root Device. Defaults to None.
        use_opsworks_security_groups(bool, optional): Whether to associate the AWS OpsWorks Stacks built-in security groups with the stack's layers. AWS OpsWorks Stacks provides a standard set of built-in security groups, one for each layer, which are associated with layers by default. UseOpsworksSecurityGroups allows you to provide your own custom security groups instead of using the built-in groups. UseOpsworksSecurityGroups has the following settings:    True - AWS OpsWorks Stacks automatically associates the appropriate built-in security group with each layer (default setting). You can associate additional security groups with a layer after you create it, but you cannot delete the built-in security group.   False - AWS OpsWorks Stacks does not associate built-in security groups with layers. You must create appropriate EC2 security groups and associate a security group with each layer that you create. However, you can still manually associate a built-in security group with a layer on. Custom security groups are required only for those layers that need custom settings.   For more information, see Create a New Stack. Defaults to None.
        agent_version(str, optional): The default AWS OpsWorks Stacks agent version. You have the following options:   Auto-update - Set this parameter to LATEST. AWS OpsWorks Stacks automatically installs new agent versions on the stack's instances as soon as they are available.   Fixed version - Set this parameter to your preferred agent version. To update the agent version, you must edit the stack configuration and specify a new version. AWS OpsWorks Stacks then automatically installs that version on the stack's instances.   The default setting is LATEST. To specify an agent version, you must use the complete version number, not the abbreviated number shown on the console. For a list of available agent version numbers, call DescribeAgentVersions. AgentVersion cannot be set to Chef 12.2.  You can also specify an agent version when you create or update an instance, which overrides the stack's default setting. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.stack.init.update(ctx, stack_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.stack.init.update stack_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="update_stack",
        op_kwargs={
            "StackId": stack_id,
            "Name": name,
            "Attributes": attributes,
            "ServiceRoleArn": service_role_arn,
            "DefaultInstanceProfileArn": default_instance_profile_arn,
            "DefaultOs": default_os,
            "HostnameTheme": hostname_theme,
            "DefaultAvailabilityZone": default_availability_zone,
            "DefaultSubnetId": default_subnet_id,
            "CustomJson": custom_json,
            "ConfigurationManager": configuration_manager,
            "ChefConfiguration": chef_configuration,
            "UseCustomCookbooks": use_custom_cookbooks,
            "CustomCookbooksSource": custom_cookbooks_source,
            "DefaultSshKeyName": default_ssh_key_name,
            "DefaultRootDeviceType": default_root_device_type,
            "UseOpsworksSecurityGroups": use_opsworks_security_groups,
            "AgentVersion": agent_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    filters: List = None,
    availability_zone: str = None,
    dry_run: bool = None,
    end_time: str = None,
    instance_types: List = None,
    max_results: int = None,
    next_token: str = None,
    product_descriptions: List = None,
    start_time: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the Spot price history. For more information, see Spot Instance pricing history in the Amazon EC2 User Guide for Linux Instances. When you specify a start and end time, the operation returns the prices of the instance types within that time range. It also returns the last price change before the start time, which is the effective price as of the start time.

    Args:
        filters(List, optional): One or more filters.    availability-zone - The Availability Zone for which prices should be returned.    instance-type - The type of instance (for example, m3.medium).    product-description - The product description for the Spot price (Linux/UNIX | Red Hat Enterprise Linux | SUSE Linux | Windows | Linux/UNIX (Amazon VPC) | Red Hat Enterprise Linux (Amazon VPC) | SUSE Linux (Amazon VPC) | Windows (Amazon VPC)).    spot-price - The Spot price. The value must match exactly (or use wildcards; greater than or less than comparison is not supported).    timestamp - The time stamp of the Spot price history, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ). You can use wildcards (* and ?). Greater than or less than comparison is not supported.  . Defaults to None.
        availability_zone(str, optional): Filters the results by the specified Availability Zone. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        end_time(str, optional): The date and time, up to the current date, from which to stop retrieving the price history data, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ). Defaults to None.
        instance_types(List, optional): Filters the results by the specified instance types. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Specify a value between 1 and 1000. The default value is 1000. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        product_descriptions(List, optional): Filters the results by the specified basic product descriptions. Defaults to None.
        start_time(str, optional): The date and time, up to the past 90 days, from which to start retrieving the price history data, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.spot.price_history.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.spot.price_history.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_spot_price_history",
        op_kwargs={
            "Filters": filters,
            "AvailabilityZone": availability_zone,
            "DryRun": dry_run,
            "EndTime": end_time,
            "InstanceTypes": instance_types,
            "MaxResults": max_results,
            "NextToken": next_token,
            "ProductDescriptions": product_descriptions,
            "StartTime": start_time,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def admin(hub, ctx, user_pool_id: str, username: str, mfa_options: List) -> Dict:
    r"""
    **Autogenerated function**

     This action is no longer supported. You can use it to configure only SMS MFA. You can't use it to configure TOTP software token MFA. To configure either type of MFA, use AdminSetUserMFAPreference instead.

    Args:
        user_pool_id(str): The ID of the user pool that contains the user that you are setting options for.
        username(str): The user name of the user that you are setting options for.
        mfa_options(List): You can use this parameter only to set an SMS configuration that uses SMS for delivery.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.set_user.setting.admin(
                ctx, user_pool_id=value, username=value, mfa_options=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.set_user.setting.admin user_pool_id=value, username=value, mfa_options=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="admin_set_user_settings",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "Username": username,
            "MFAOptions": mfa_options,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, table_name: str, backup_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a backup for an existing table.  Each time you create an on-demand backup, the entire table data is backed up. There is no limit to the number of on-demand backups that can be taken.   When you create an on-demand backup, a time marker of the request is cataloged, and the backup is created asynchronously, by applying all changes until the time of the request to the last full table snapshot. Backup requests are processed instantaneously and become available for restore within minutes.  You can call CreateBackup at a maximum rate of 50 times per second. All backups in DynamoDB work without consuming any provisioned throughput on the table.  If you submit a backup request on 2018-12-14 at 14:25:00, the backup is guaranteed to contain all data committed to the table up to 14:24:00, and data committed after 14:26:00 will not be. The backup might contain data modifications made between 14:24:00 and 14:26:00. On-demand backup does not support causal consistency.   Along with data, the following are also included on the backups:    Global secondary indexes (GSIs)   Local secondary indexes (LSIs)   Streams   Provisioned read and write capacity

    Args:
        table_name(str): The name of the table.
        backup_name(str): Specified name for the backup.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.backup.create(ctx, table_name=value, backup_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.backup.create table_name=value, backup_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="create_backup",
        op_kwargs={"TableName": table_name, "BackupName": backup_name},
    )


async def delete(hub, ctx, backup_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing backup of a table. You can call DeleteBackup at a maximum rate of 10 times per second.

    Args:
        backup_arn(str): The ARN associated with the backup.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.backup.delete(ctx, backup_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.backup.delete backup_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="delete_backup",
        op_kwargs={"BackupArn": backup_arn},
    )


async def describe(hub, ctx, backup_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an existing backup of a table. You can call DescribeBackup at a maximum rate of 10 times per second.

    Args:
        backup_arn(str): The Amazon Resource Name (ARN) associated with the backup.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.backup.describe(ctx, backup_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.backup.describe backup_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="describe_backup",
        op_kwargs={"BackupArn": backup_arn},
    )


async def list_all(
    hub,
    ctx,
    table_name: str = None,
    limit: int = None,
    time_range_lower_bound: str = None,
    time_range_upper_bound: str = None,
    exclusive_start_backup_arn: str = None,
    backup_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List backups associated with an AWS account. To list backups for a given table, specify TableName. ListBackups returns a paginated list of results with at most 1 MB worth of items in a page. You can also specify a maximum number of entries to be returned in a page.  In the request, start time is inclusive, but end time is exclusive. Note that these boundaries are for the time at which the original backup was requested. You can call ListBackups a maximum of five times per second.

    Args:
        table_name(str, optional): The backups from the table specified by TableName are listed. . Defaults to None.
        limit(int, optional): Maximum number of backups to return at once. Defaults to None.
        time_range_lower_bound(str, optional): Only backups created after this time are listed. TimeRangeLowerBound is inclusive. Defaults to None.
        time_range_upper_bound(str, optional): Only backups created before this time are listed. TimeRangeUpperBound is exclusive. . Defaults to None.
        exclusive_start_backup_arn(str, optional):  LastEvaluatedBackupArn is the Amazon Resource Name (ARN) of the backup last evaluated when the current page of results was returned, inclusive of the current page of results. This value may be specified as the ExclusiveStartBackupArn of a new ListBackups operation in order to fetch the next page of results. . Defaults to None.
        backup_type(str, optional): The backups from the table specified by BackupType are listed. Where BackupType can be:    USER - On-demand backup created by you.    SYSTEM - On-demand backup automatically created by DynamoDB.    ALL - All types of on-demand backups (USER and SYSTEM).  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.backup.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.backup.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="list_backups",
        op_kwargs={
            "TableName": table_name,
            "Limit": limit,
            "TimeRangeLowerBound": time_range_lower_bound,
            "TimeRangeUpperBound": time_range_upper_bound,
            "ExclusiveStartBackupArn": exclusive_start_backup_arn,
            "BackupType": backup_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    clip_fragment_selector: Dict,
    stream_name: str = None,
    stream_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Downloads an MP4 file (clip) containing the archived, on-demand media from the specified video stream over the specified time range.  Both the StreamName and the StreamARN parameters are optional, but you must specify either the StreamName or the StreamARN when invoking this API operation.  As a prerequisite to using GetCLip API, you must obtain an endpoint using GetDataEndpoint, specifying GET_CLIP for the APIName parameter.  An Amazon Kinesis video stream has the following requirements for providing data through MP4:   The media must contain h.264 or h.265 encoded video and, optionally, AAC or G.711 encoded audio. Specifically, the codec ID of track 1 should be V_MPEG/ISO/AVC (for h.264) or V_MPEGH/ISO/HEVC (for H.265). Optionally, the codec ID of track 2 should be A_AAC (for AAC) or A_MS/ACM (for G.711).   Data retention must be greater than 0.   The video track of each fragment must contain codec private data in the Advanced Video Coding (AVC) for H.264 format and HEVC for H.265 format. For more information, see MPEG-4 specification ISO/IEC 14496-15. For information about adapting stream data to a given format, see NAL Adaptation Flags.   The audio track (if present) of each fragment must contain codec private data in the AAC format (AAC specification ISO/IEC 13818-7) or the MS Wave format.   You can monitor the amount of outgoing data by monitoring the GetClip.OutgoingBytes Amazon CloudWatch metric. For information about using CloudWatch to monitor Kinesis Video Streams, see Monitoring Kinesis Video Streams. For pricing information, see Amazon Kinesis Video Streams Pricing and AWS Pricing. Charges for outgoing AWS data apply.

    Args:
        stream_name(str, optional): The name of the stream for which to retrieve the media clip.  You must specify either the StreamName or the StreamARN. . Defaults to None.
        stream_arn(str, optional): The Amazon Resource Name (ARN) of the stream for which to retrieve the media clip.  You must specify either the StreamName or the StreamARN. . Defaults to None.
        clip_fragment_selector(Dict): The time range of the requested clip and the source of the timestamps.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis_video_archived_media.clip.get(
                ctx, clip_fragment_selector=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis_video_archived_media.clip.get clip_fragment_selector=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis-video-archived-media",
        operation="get_clip",
        op_kwargs={
            "StreamName": stream_name,
            "StreamARN": stream_arn,
            "ClipFragmentSelector": clip_fragment_selector,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a suite.

    Args:
        arn(str): The suite's ARN.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.suite.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.suite.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="devicefarm", operation="get_suite", op_kwargs={"arn": arn}
    )


async def list_all(hub, ctx, arn: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about test suites for a given job.

    Args:
        arn(str): The job's Amazon Resource Name (ARN).
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.suite.list_all(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.suite.list_all arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="list_suites",
        op_kwargs={"arn": arn, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, rule: Dict, description: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates a rule's metadata. The description attribute can be updated.

    Args:
        rule(Dict): The rule to update.
        description(str): The rule description.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.rule.metadata.update(
                ctx, rule=value, description=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.rule.metadata.update rule=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="update_rule_metadata",
        op_kwargs={"rule": rule, "description": description},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, metric_widget: str, output_format: str = None) -> Dict:
    r"""
    **Autogenerated function**

    You can use the GetMetricWidgetImage API to retrieve a snapshot graph of one or more Amazon CloudWatch metrics as a bitmap image. You can then embed this image into your services and products, such as wiki pages, reports, and documents. You could also retrieve images regularly, such as every minute, and create your own custom live dashboard. The graph you retrieve can include all CloudWatch metric graph features, including metric math and horizontal and vertical annotations. There is a limit of 20 transactions per second for this API. Each GetMetricWidgetImage action has the following limits:   As many as 100 metrics in the graph.   Up to 100 KB uncompressed payload.

    Args:
        metric_widget(str): A JSON string that defines the bitmap graph to be retrieved. The string includes the metrics to include in the graph, statistics, annotations, title, axis limits, and so on. You can include only one MetricWidget parameter in each GetMetricWidgetImage call. For more information about the syntax of MetricWidget see GetMetricWidgetImage: Metric Widget Structure and Syntax. If any metric on the graph could not load all the requested data points, an orange triangle with an exclamation point appears next to the graph legend.
        output_format(str, optional): The format of the resulting image. Only PNG images are supported. The default is png. If you specify png, the API returns an HTTP response with the content-type set to text/xml. The image data is in a MetricWidgetImage field. For example:   <GetMetricWidgetImageResponse xmlns=<URLstring>>    <GetMetricWidgetImageResult>    <MetricWidgetImage>    iVBORw0KGgoAAAANSUhEUgAAAlgAAAGQEAYAAAAip...    </MetricWidgetImage>    </GetMetricWidgetImageResult>    <ResponseMetadata>    <RequestId>6f0d4192-4d42-11e8-82c1-f539a07e0e3b</RequestId>    </ResponseMetadata>   </GetMetricWidgetImageResponse>  The image/png setting is intended only for custom HTTP requests. For most use cases, and all actions using an Amazon Web Services SDK, you should use png. If you specify image/png, the HTTP response has a content-type set to image/png, and the body of the response is a PNG image. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.metric.widget_image.get(ctx, metric_widget=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.metric.widget_image.get metric_widget=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="get_metric_widget_image",
        op_kwargs={"MetricWidget": metric_widget, "OutputFormat": output_format},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def deregister(
    hub,
    ctx,
    db_proxy_name: str,
    target_group_name: str = None,
    db_instance_identifiers: List = None,
    db_cluster_identifiers: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Remove the association between one or more DBProxyTarget data structures and a DBProxyTargetGroup.

    Args:
        db_proxy_name(str): The identifier of the DBProxy that is associated with the DBProxyTargetGroup.
        target_group_name(str, optional): The identifier of the DBProxyTargetGroup. Defaults to None.
        db_instance_identifiers(List, optional): One or more DB instance identifiers. Defaults to None.
        db_cluster_identifiers(List, optional): One or more DB cluster identifiers. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.proxy.target.init.deregister(ctx, db_proxy_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.proxy.target.init.deregister db_proxy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="deregister_db_proxy_targets",
        op_kwargs={
            "DBProxyName": db_proxy_name,
            "TargetGroupName": target_group_name,
            "DBInstanceIdentifiers": db_instance_identifiers,
            "DBClusterIdentifiers": db_cluster_identifiers,
        },
    )


async def describe_all(
    hub,
    ctx,
    db_proxy_name: str,
    target_group_name: str = None,
    filters: List = None,
    marker: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about DBProxyTarget objects. This API supports pagination.

    Args:
        db_proxy_name(str): The identifier of the DBProxyTarget to describe.
        target_group_name(str, optional): The identifier of the DBProxyTargetGroup to describe. Defaults to None.
        filters(List, optional): This parameter is not currently supported. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.proxy.target.init.describe_all(ctx, db_proxy_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.proxy.target.init.describe_all db_proxy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_db_proxy_targets",
        op_kwargs={
            "DBProxyName": db_proxy_name,
            "TargetGroupName": target_group_name,
            "Filters": filters,
            "Marker": marker,
            "MaxRecords": max_records,
        },
    )


async def register(
    hub,
    ctx,
    db_proxy_name: str,
    target_group_name: str = None,
    db_instance_identifiers: List = None,
    db_cluster_identifiers: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associate one or more DBProxyTarget data structures with a DBProxyTargetGroup.

    Args:
        db_proxy_name(str): The identifier of the DBProxy that is associated with the DBProxyTargetGroup.
        target_group_name(str, optional): The identifier of the DBProxyTargetGroup. Defaults to None.
        db_instance_identifiers(List, optional): One or more DB instance identifiers. Defaults to None.
        db_cluster_identifiers(List, optional): One or more DB cluster identifiers. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.proxy.target.init.register(ctx, db_proxy_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.proxy.target.init.register db_proxy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="register_db_proxy_targets",
        op_kwargs={
            "DBProxyName": db_proxy_name,
            "TargetGroupName": target_group_name,
            "DBInstanceIdentifiers": db_instance_identifiers,
            "DBClusterIdentifiers": db_cluster_identifiers,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    hit_id: str,
    number_of_additional_assignments: int,
    unique_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The CreateAdditionalAssignmentsForHIT operation increases the maximum number of assignments of an existing HIT.   To extend the maximum number of assignments, specify the number of additional assignments.    HITs created with fewer than 10 assignments cannot be extended to have 10 or more assignments. Attempting to add assignments in a way that brings the total number of assignments for a HIT from fewer than 10 assignments to 10 or more assignments will result in an AWS.MechanicalTurk.InvalidMaximumAssignmentsIncrease exception.   HITs that were created before July 22, 2015 cannot be extended. Attempting to extend HITs that were created before July 22, 2015 will result in an AWS.MechanicalTurk.HITTooOldForExtension exception.

    Args:
        hit_id(str): The ID of the HIT to extend.
        number_of_additional_assignments(int): The number of additional assignments to request for this HIT.
        unique_request_token(str, optional):  A unique identifier for this request, which allows you to retry the call on error without extending the HIT multiple times. This is useful in cases such as network timeouts where it is unclear whether or not the call succeeded on the server. If the extend HIT already exists in the system from a previous call using the same UniqueRequestToken, subsequent calls will return an error with a message containing the request ID. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.additional_assignment_for_hit.create(
                ctx, hit_id=value, number_of_additional_assignments=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.additional_assignment_for_hit.create hit_id=value, number_of_additional_assignments=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="create_additional_assignments_for_hit",
        op_kwargs={
            "HITId": hit_id,
            "NumberOfAdditionalAssignments": number_of_additional_assignments,
            "UniqueRequestToken": unique_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def put_multiple(hub, ctx, trace_segment_documents: List) -> Dict:
    r"""
    **Autogenerated function**

    Uploads segment documents to AWS X-Ray. The X-Ray SDK generates segment documents and sends them to the X-Ray daemon, which uploads them in batches. A segment document can be a completed segment, an in-progress segment, or an array of subsegments. Segments must include the following fields. For the full segment document schema, see AWS X-Ray Segment Documents in the AWS X-Ray Developer Guide.  Required segment document fields     name - The name of the service that handled the request.    id - A 64-bit identifier for the segment, unique among segments in the same trace, in 16 hexadecimal digits.    trace_id - A unique identifier that connects all segments and subsegments originating from a single client request.    start_time - Time the segment or subsegment was created, in floating point seconds in epoch time, accurate to milliseconds. For example, 1480615200.010 or 1.480615200010E9.    end_time - Time the segment or subsegment was closed. For example, 1480615200.090 or 1.480615200090E9. Specify either an end_time or in_progress.    in_progress - Set to true instead of specifying an end_time to record that a segment has been started, but is not complete. Send an in-progress segment when your application receives a request that will take a long time to serve, to trace that the request was received. When the response is sent, send the complete segment to overwrite the in-progress segment.   A trace_id consists of three numbers separated by hyphens. For example, 1-58406520-a006649127e371903a2de979. This includes:  Trace ID Format    The version number, for instance, 1.   The time of the original request, in Unix epoch time, in 8 hexadecimal digits. For example, 10:00AM December 2nd, 2016 PST in epoch time is 1480615200 seconds, or 58406520 in hexadecimal.   A 96-bit identifier for the trace, globally unique, in 24 hexadecimal digits.

    Args:
        trace_segment_documents(List): A string containing a JSON document defining one or more segments or subsegments.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.trace.segment.put_multiple(
                ctx, trace_segment_documents=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.trace.segment.put_multiple trace_segment_documents=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="put_trace_segments",
        op_kwargs={"TraceSegmentDocuments": trace_segment_documents},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete_multiple(hub, ctx, config_rule_name: str, resource_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes one or more remediation exceptions mentioned in the resource keys.  AWS Config generates a remediation exception when a problem occurs executing a remediation action to a specific resource. Remediation exceptions blocks auto-remediation until the exception is cleared.

    Args:
        config_rule_name(str): The name of the AWS Config rule for which you want to delete remediation exception configuration.
        resource_keys(List): An exception list of resource exception keys to be processed with the current request. AWS Config adds exception for each resource key. For example, AWS Config adds 3 exceptions for 3 resource keys. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.remediation.exception.delete_multiple(
                ctx, config_rule_name=value, resource_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.remediation.exception.delete_multiple config_rule_name=value, resource_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="delete_remediation_exceptions",
        op_kwargs={"ConfigRuleName": config_rule_name, "ResourceKeys": resource_keys},
    )


async def describe_all(
    hub,
    ctx,
    config_rule_name: str,
    resource_keys: List = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the details of one or more remediation exceptions. A detailed view of a remediation exception for a set of resources that includes an explanation of an exception and the time when the exception will be deleted. When you specify the limit and the next token, you receive a paginated response.   AWS Config generates a remediation exception when a problem occurs executing a remediation action to a specific resource. Remediation exceptions blocks auto-remediation until the exception is cleared. When you specify the limit and the next token, you receive a paginated response.  Limit and next token are not applicable if you request resources in batch. It is only applicable, when you request all resources.

    Args:
        config_rule_name(str): The name of the AWS Config rule.
        resource_keys(List, optional): An exception list of resource exception keys to be processed with the current request. AWS Config adds exception for each resource key. For example, AWS Config adds 3 exceptions for 3 resource keys. . Defaults to None.
        limit(int, optional): The maximum number of RemediationExceptionResourceKey returned on each page. The default is 25. If you specify 0, AWS Config uses the default. Defaults to None.
        next_token(str, optional): The nextToken string returned in a previous request that you use to request the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.remediation.exception.describe_all(
                ctx, config_rule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.remediation.exception.describe_all config_rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_remediation_exceptions",
        op_kwargs={
            "ConfigRuleName": config_rule_name,
            "ResourceKeys": resource_keys,
            "Limit": limit,
            "NextToken": next_token,
        },
    )


async def put_multiple(
    hub,
    ctx,
    config_rule_name: str,
    resource_keys: List,
    message: str = None,
    expiration_time: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    A remediation exception is when a specific resource is no longer considered for auto-remediation. This API adds a new exception or updates an existing exception for a specific resource with a specific AWS Config rule.   AWS Config generates a remediation exception when a problem occurs executing a remediation action to a specific resource. Remediation exceptions blocks auto-remediation until the exception is cleared.

    Args:
        config_rule_name(str): The name of the AWS Config rule for which you want to create remediation exception.
        resource_keys(List): An exception list of resource exception keys to be processed with the current request. AWS Config adds exception for each resource key. For example, AWS Config adds 3 exceptions for 3 resource keys. .
        message(str, optional): The message contains an explanation of the exception. Defaults to None.
        expiration_time(str, optional): The exception is automatically deleted after the expiration date. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.remediation.exception.put_multiple(
                ctx, config_rule_name=value, resource_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.remediation.exception.put_multiple config_rule_name=value, resource_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="put_remediation_exceptions",
        op_kwargs={
            "ConfigRuleName": config_rule_name,
            "ResourceKeys": resource_keys,
            "Message": message,
            "ExpirationTime": expiration_time,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    stack_set_name: str,
    description: str = None,
    template_body: str = None,
    template_url: str = None,
    stack_id: str = None,
    parameters: List = None,
    capabilities: List = None,
    tags: List = None,
    administration_role_arn: str = None,
    execution_role_name: str = None,
    permission_model: str = None,
    auto_deployment: Dict = None,
    call_as: str = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a stack set.

    Args:
        stack_set_name(str): The name to associate with the stack set. The name must be unique in the Region where you create your stack set.  A stack name can contain only alphanumeric characters (case-sensitive) and hyphens. It must start with an alphabetic character and can't be longer than 128 characters. .
        description(str, optional): A description of the stack set. You can use the description to identify the stack set's purpose or other important information. Defaults to None.
        template_body(str, optional): The structure that contains the template body, with a minimum length of 1 byte and a maximum length of 51,200 bytes. For more information, see Template Anatomy in the CloudFormation User Guide. Conditional: You must specify either the TemplateBody or the TemplateURL parameter, but not both. Defaults to None.
        template_url(str, optional): The location of the file that contains the template body. The URL must point to a template (maximum size: 460,800 bytes) that's located in an Amazon S3 bucket or a Systems Manager document. For more information, see Template Anatomy in the CloudFormation User Guide. Conditional: You must specify either the TemplateBody or the TemplateURL parameter, but not both. Defaults to None.
        stack_id(str, optional): The stack ID you are importing into a new stack set. Specify the Amazon Resource Number (ARN) of the stack. Defaults to None.
        parameters(List, optional): The input parameters for the stack set template. . Defaults to None.
        capabilities(List, optional): In some cases, you must explicitly acknowledge that your stack set template contains certain capabilities in order for CloudFormation to create the stack set and related stack instances.    CAPABILITY_IAM and CAPABILITY_NAMED_IAM  Some stack templates might include resources that can affect permissions in your account; for example, by creating new Identity and Access Management (IAM) users. For those stack sets, you must explicitly acknowledge this by specifying one of these capabilities. The following IAM resources require you to specify either the CAPABILITY_IAM or CAPABILITY_NAMED_IAM capability.   If you have IAM resources, you can specify either capability.    If you have IAM resources with custom names, you must specify CAPABILITY_NAMED_IAM.    If you don't specify either of these capabilities, CloudFormation returns an InsufficientCapabilities error.   If your stack template contains these resources, we recommend that you review all permissions associated with them and edit their permissions if necessary.     AWS::IAM::AccessKey      AWS::IAM::Group      AWS::IAM::InstanceProfile      AWS::IAM::Policy      AWS::IAM::Role      AWS::IAM::User      AWS::IAM::UserToGroupAddition    For more information, see Acknowledging IAM Resources in CloudFormation Templates.    CAPABILITY_AUTO_EXPAND  Some templates reference macros. If your stack set template references one or more macros, you must create the stack set directly from the processed template, without first reviewing the resulting changes in a change set. To create the stack set directly, you must acknowledge this capability. For more information, see Using CloudFormation Macros to Perform Custom Processing on Templates.  Stack sets with service-managed permissions do not currently support the use of macros in templates. (This includes the AWS::Include and AWS::Serverless transforms, which are macros hosted by CloudFormation.) Even if you specify this capability for a stack set with service-managed permissions, if you reference a macro in your template the stack set operation will fail.   . Defaults to None.
        tags(List, optional): The key-value pairs to associate with this stack set and the stacks created from it. CloudFormation also propagates these tags to supported resources that are created in the stacks. A maximum number of 50 tags can be specified. If you specify tags as part of a CreateStackSet action, CloudFormation checks to see if you have the required IAM permission to tag resources. If you don't, the entire CreateStackSet action fails with an access denied error, and the stack set is not created. Defaults to None.
        administration_role_arn(str, optional): The Amazon Resource Number (ARN) of the IAM role to use to create this stack set.  Specify an IAM role only if you are using customized administrator roles to control which users or groups can manage specific stack sets within the same administrator account. For more information, see Prerequisites: Granting Permissions for Stack Set Operations in the CloudFormation User Guide. Defaults to None.
        execution_role_name(str, optional): The name of the IAM execution role to use to create the stack set. If you do not specify an execution role, CloudFormation uses the AWSCloudFormationStackSetExecutionRole role for the stack set operation. Specify an IAM role only if you are using customized execution roles to control which stack resources users and groups can include in their stack sets. . Defaults to None.
        permission_model(str, optional): Describes how the IAM roles required for stack set operations are created. By default, SELF-MANAGED is specified.   With self-managed permissions, you must create the administrator and execution roles required to deploy to target accounts. For more information, see Grant Self-Managed Stack Set Permissions.   With service-managed permissions, StackSets automatically creates the IAM roles required to deploy to accounts managed by Organizations. For more information, see Grant Service-Managed Stack Set Permissions.  . Defaults to None.
        auto_deployment(Dict, optional): Describes whether StackSets automatically deploys to Organizations accounts that are added to the target organization or organizational unit (OU). Specify only if PermissionModel is SERVICE_MANAGED. Defaults to None.
        call_as(str, optional): [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account. By default, SELF is specified. Use SELF for stack sets with self-managed permissions.   To create a stack set with service-managed permissions while signed in to the management account, specify SELF.   To create a stack set with service-managed permissions while signed in to a delegated administrator account, specify DELEGATED_ADMIN. Your account must be registered as a delegated admin in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.   Stack sets with service-managed permissions are created in the management account, including stack sets that are created by delegated administrators. Defaults to None.
        client_request_token(str, optional): A unique identifier for this CreateStackSet request. Specify this token if you plan to retry requests so that CloudFormation knows that you're not attempting to create another stack set with the same name. You might retry CreateStackSet requests to ensure that CloudFormation successfully received them. If you don't specify an operation ID, the SDK generates one automatically. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.set_.init.create(ctx, stack_set_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.set_.init.create stack_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="create_stack_set",
        op_kwargs={
            "StackSetName": stack_set_name,
            "Description": description,
            "TemplateBody": template_body,
            "TemplateURL": template_url,
            "StackId": stack_id,
            "Parameters": parameters,
            "Capabilities": capabilities,
            "Tags": tags,
            "AdministrationRoleARN": administration_role_arn,
            "ExecutionRoleName": execution_role_name,
            "PermissionModel": permission_model,
            "AutoDeployment": auto_deployment,
            "CallAs": call_as,
            "ClientRequestToken": client_request_token,
        },
    )


async def delete(hub, ctx, stack_set_name: str, call_as: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a stack set. Before you can delete a stack set, all of its member stack instances must be deleted. For more information about how to do this, see DeleteStackInstances.

    Args:
        stack_set_name(str): The name or unique ID of the stack set that you're deleting. You can obtain this value by running ListStackSets.
        call_as(str, optional): [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account. By default, SELF is specified. Use SELF for stack sets with self-managed permissions.   If you are signed in to the management account, specify SELF.   If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN. Your account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.set_.init.delete(ctx, stack_set_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.set_.init.delete stack_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="delete_stack_set",
        op_kwargs={"StackSetName": stack_set_name, "CallAs": call_as},
    )


async def describe(hub, ctx, stack_set_name: str, call_as: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the description of the specified stack set.

    Args:
        stack_set_name(str): The name or unique ID of the stack set whose description you want.
        call_as(str, optional): [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account. By default, SELF is specified. Use SELF for stack sets with self-managed permissions.   If you are signed in to the management account, specify SELF.   If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN. Your account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.set_.init.describe(
                ctx, stack_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.set_.init.describe stack_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="describe_stack_set",
        op_kwargs={"StackSetName": stack_set_name, "CallAs": call_as},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    status: str = None,
    call_as: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns summary information about stack sets that are associated with the user.   [Self-managed permissions] If you set the CallAs parameter to SELF while signed in to your account, ListStackSets returns all self-managed stack sets in your account.   [Service-managed permissions] If you set the CallAs parameter to SELF while signed in to the organization's management account, ListStackSets returns all stack sets in the management account.   [Service-managed permissions] If you set the CallAs parameter to DELEGATED_ADMIN while signed in to your member account, ListStackSets returns all stack sets with service-managed permissions in the management account.

    Args:
        next_token(str, optional): If the previous paginated request didn't return all of the remaining results, the response object's NextToken parameter value is set to a token. To retrieve the next set of results, call ListStackSets again and assign that token to the request object's NextToken parameter. If there are no remaining results, the previous response object's NextToken parameter is set to null. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned with a single call. If the number of available results exceeds this maximum, the response includes a NextToken value that you can assign to the NextToken request parameter to get the next set of results. Defaults to None.
        status(str, optional): The status of the stack sets that you want to get summary information about. Defaults to None.
        call_as(str, optional): [Service-managed permissions] Specifies whether you are acting as an account administrator in the management account or as a delegated administrator in a member account. By default, SELF is specified. Use SELF for stack sets with self-managed permissions.   If you are signed in to the management account, specify SELF.   If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN. Your account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.set_.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.set_.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="list_stack_sets",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Status": status,
            "CallAs": call_as,
        },
    )


async def update(
    hub,
    ctx,
    stack_set_name: str,
    description: str = None,
    template_body: str = None,
    template_url: str = None,
    use_previous_template: bool = None,
    parameters: List = None,
    capabilities: List = None,
    tags: List = None,
    operation_preferences: Dict = None,
    administration_role_arn: str = None,
    execution_role_name: str = None,
    deployment_targets: Dict = None,
    permission_model: str = None,
    auto_deployment: Dict = None,
    operation_id: str = None,
    accounts: List = None,
    regions: List = None,
    call_as: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the stack set, and associated stack instances in the specified accounts and Regions. Even if the stack set operation created by updating the stack set fails (completely or partially, below or above a specified failure tolerance), the stack set is updated with your changes. Subsequent CreateStackInstances calls on the specified stack set use the updated stack set.

    Args:
        stack_set_name(str): The name or unique ID of the stack set that you want to update.
        description(str, optional): A brief description of updates that you are making. Defaults to None.
        template_body(str, optional): The structure that contains the template body, with a minimum length of 1 byte and a maximum length of 51,200 bytes. For more information, see Template Anatomy in the CloudFormation User Guide. Conditional: You must specify only one of the following parameters: TemplateBody or TemplateURL—or set UsePreviousTemplate to true. Defaults to None.
        template_url(str, optional): The location of the file that contains the template body. The URL must point to a template (maximum size: 460,800 bytes) that is located in an Amazon S3 bucket or a Systems Manager document. For more information, see Template Anatomy in the CloudFormation User Guide. Conditional: You must specify only one of the following parameters: TemplateBody or TemplateURL—or set UsePreviousTemplate to true. . Defaults to None.
        use_previous_template(bool, optional): Use the existing template that's associated with the stack set that you're updating. Conditional: You must specify only one of the following parameters: TemplateBody or TemplateURL—or set UsePreviousTemplate to true. . Defaults to None.
        parameters(List, optional): A list of input parameters for the stack set template. . Defaults to None.
        capabilities(List, optional): In some cases, you must explicitly acknowledge that your stack template contains certain capabilities in order for CloudFormation to update the stack set and its associated stack instances.    CAPABILITY_IAM and CAPABILITY_NAMED_IAM  Some stack templates might include resources that can affect permissions in your account; for example, by creating new Identity and Access Management (IAM) users. For those stacks sets, you must explicitly acknowledge this by specifying one of these capabilities. The following IAM resources require you to specify either the CAPABILITY_IAM or CAPABILITY_NAMED_IAM capability.   If you have IAM resources, you can specify either capability.    If you have IAM resources with custom names, you must specify CAPABILITY_NAMED_IAM.    If you don't specify either of these capabilities, CloudFormation returns an InsufficientCapabilities error.   If your stack template contains these resources, we recommend that you review all permissions associated with them and edit their permissions if necessary.     AWS::IAM::AccessKey      AWS::IAM::Group      AWS::IAM::InstanceProfile      AWS::IAM::Policy      AWS::IAM::Role      AWS::IAM::User      AWS::IAM::UserToGroupAddition    For more information, see Acknowledging IAM Resources in CloudFormation Templates.    CAPABILITY_AUTO_EXPAND  Some templates reference macros. If your stack set template references one or more macros, you must update the stack set directly from the processed template, without first reviewing the resulting changes in a change set. To update the stack set directly, you must acknowledge this capability. For more information, see Using CloudFormation Macros to Perform Custom Processing on Templates.  Stack sets with service-managed permissions do not currently support the use of macros in templates. (This includes the AWS::Include and AWS::Serverless transforms, which are macros hosted by CloudFormation.) Even if you specify this capability for a stack set with service-managed permissions, if you reference a macro in your template the stack set operation will fail.   . Defaults to None.
        tags(List, optional): The key-value pairs to associate with this stack set and the stacks created from it. CloudFormation also propagates these tags to supported resources that are created in the stacks. You can specify a maximum number of 50 tags. If you specify tags for this parameter, those tags replace any list of tags that are currently associated with this stack set. This means:   If you don't specify this parameter, CloudFormation doesn't modify the stack's tags.    If you specify any tags using this parameter, you must specify all the tags that you want associated with this stack set, even tags you've specifed before (for example, when creating the stack set or during a previous update of the stack set.). Any tags that you don't include in the updated list of tags are removed from the stack set, and therefore from the stacks and resources as well.    If you specify an empty value, CloudFormation removes all currently associated tags.   If you specify new tags as part of an UpdateStackSet action, CloudFormation checks to see if you have the required IAM permission to tag resources. If you omit tags that are currently associated with the stack set from the list of tags you specify, CloudFormation assumes that you want to remove those tags from the stack set, and checks to see if you have permission to untag resources. If you don't have the necessary permission(s), the entire UpdateStackSet action fails with an access denied error, and the stack set is not updated. Defaults to None.
        operation_preferences(Dict, optional): Preferences for how CloudFormation performs this stack set operation. Defaults to None.
        administration_role_arn(str, optional): The Amazon Resource Number (ARN) of the IAM role to use to update this stack set. Specify an IAM role only if you are using customized administrator roles to control which users or groups can manage specific stack sets within the same administrator account. For more information, see Granting Permissions for Stack Set Operations in the CloudFormation User Guide. If you specified a customized administrator role when you created the stack set, you must specify a customized administrator role, even if it is the same customized administrator role used with this stack set previously. Defaults to None.
        execution_role_name(str, optional): The name of the IAM execution role to use to update the stack set. If you do not specify an execution role, CloudFormation uses the AWSCloudFormationStackSetExecutionRole role for the stack set operation. Specify an IAM role only if you are using customized execution roles to control which stack resources users and groups can include in their stack sets.   If you specify a customized execution role, CloudFormation uses that role to update the stack. If you do not specify a customized execution role, CloudFormation performs the update using the role previously associated with the stack set, so long as you have permissions to perform operations on the stack set. Defaults to None.
        deployment_targets(Dict, optional): [Service-managed permissions] The Organizations accounts in which to update associated stack instances. To update all the stack instances associated with this stack set, do not specify DeploymentTargets or Regions. If the stack set update includes changes to the template (that is, if TemplateBody or TemplateURL is specified), or the Parameters, CloudFormation marks all stack instances with a status of OUTDATED prior to updating the stack instances in the specified accounts and Regions. If the stack set update does not include changes to the template or parameters, CloudFormation updates the stack instances in the specified accounts and Regions, while leaving all other stack instances with their existing stack instance status. Defaults to None.
        permission_model(str, optional): Describes how the IAM roles required for stack set operations are created. You cannot modify PermissionModel if there are stack instances associated with your stack set.   With self-managed permissions, you must create the administrator and execution roles required to deploy to target accounts. For more information, see Grant Self-Managed Stack Set Permissions.   With service-managed permissions, StackSets automatically creates the IAM roles required to deploy to accounts managed by Organizations. For more information, see Grant Service-Managed Stack Set Permissions.  . Defaults to None.
        auto_deployment(Dict, optional): [Service-managed permissions] Describes whether StackSets automatically deploys to Organizations accounts that are added to a target organization or organizational unit (OU). If you specify AutoDeployment, do not specify DeploymentTargets or Regions. Defaults to None.
        operation_id(str, optional): The unique ID for this stack set operation.  The operation ID also functions as an idempotency token, to ensure that CloudFormation performs the stack set operation only once, even if you retry the request multiple times. You might retry stack set operation requests to ensure that CloudFormation successfully received them. If you don't specify an operation ID, CloudFormation generates one automatically. Repeating this stack set operation with a new operation ID retries all stack instances whose status is OUTDATED. . Defaults to None.
        accounts(List, optional): [Self-managed permissions] The accounts in which to update associated stack instances. If you specify accounts, you must also specify the Regions in which to update stack set instances. To update all the stack instances associated with this stack set, do not specify the Accounts or Regions properties. If the stack set update includes changes to the template (that is, if the TemplateBody or TemplateURL properties are specified), or the Parameters property, CloudFormation marks all stack instances with a status of OUTDATED prior to updating the stack instances in the specified accounts and Regions. If the stack set update does not include changes to the template or parameters, CloudFormation updates the stack instances in the specified accounts and Regions, while leaving all other stack instances with their existing stack instance status. . Defaults to None.
        regions(List, optional): The Regions in which to update associated stack instances. If you specify Regions, you must also specify accounts in which to update stack set instances. To update all the stack instances associated with this stack set, do not specify the Accounts or Regions properties. If the stack set update includes changes to the template (that is, if the TemplateBody or TemplateURL properties are specified), or the Parameters property, CloudFormation marks all stack instances with a status of OUTDATED prior to updating the stack instances in the specified accounts and Regions. If the stack set update does not include changes to the template or parameters, CloudFormation updates the stack instances in the specified accounts and Regions, while leaving all other stack instances with their existing stack instance status. . Defaults to None.
        call_as(str, optional): [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account. By default, SELF is specified. Use SELF for stack sets with self-managed permissions.   If you are signed in to the management account, specify SELF.   If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN. Your account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.set_.init.update(ctx, stack_set_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.set_.init.update stack_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="update_stack_set",
        op_kwargs={
            "StackSetName": stack_set_name,
            "Description": description,
            "TemplateBody": template_body,
            "TemplateURL": template_url,
            "UsePreviousTemplate": use_previous_template,
            "Parameters": parameters,
            "Capabilities": capabilities,
            "Tags": tags,
            "OperationPreferences": operation_preferences,
            "AdministrationRoleARN": administration_role_arn,
            "ExecutionRoleName": execution_role_name,
            "DeploymentTargets": deployment_targets,
            "PermissionModel": permission_model,
            "AutoDeployment": auto_deployment,
            "OperationId": operation_id,
            "Accounts": accounts,
            "Regions": regions,
            "CallAs": call_as,
        },
    )
